/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwell.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwell *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwell_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwell_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwell_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwell();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwell::Heavy_vSwell(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_4iycDuug, &hTable_AKL11do1);
  numBytes += sTabread_init(&sTabread_N9Hq4bK9, &hTable_AKL11do1, true);
  numBytes += sRPole_init(&sRPole_jAGTEifB);
  numBytes += sEnv_init(&sEnv_wXzEUNGH, 1024, 512);
  numBytes += sLine_init(&sLine_jjXeVPrI);
  numBytes += cSlice_init(&cSlice_TTN90JaE, 1, -1);
  numBytes += cSlice_init(&cSlice_ZLKIoOsS, 1, -1);
  numBytes += cVar_init_f(&cVar_whOAjkm5, 0.0f);
  numBytes += cIf_init(&cIf_OR9Z8cOF, false);
  numBytes += cBinop_init(&cBinop_hlUs0wrQ, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_aDrhnf2i, 1, -1);
  numBytes += cSlice_init(&cSlice_Pub8knoH, 1, -1);
  numBytes += cVar_init_f(&cVar_eQwgFqXN, 0.0f);
  numBytes += cIf_init(&cIf_fuRIyBjN, false);
  numBytes += cBinop_init(&cBinop_HcyzZjV5, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_XUYBC5CW, 0.0f);
  numBytes += cVar_init_f(&cVar_5T5FwRlU, 0.0f);
  numBytes += cBinop_init(&cBinop_Pc1deKhv, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_BPKADO7Z, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_ug71sBVZ, 2, 1);
  numBytes += cSlice_init(&cSlice_jwiqJMut, 1, 1);
  numBytes += cSlice_init(&cSlice_Ae9208Ic, 0, 1);
  numBytes += cVar_init_f(&cVar_kUCaDqhr, 0.0f);
  numBytes += cIf_init(&cIf_VQO1AD81, false);
  numBytes += cIf_init(&cIf_ylqguSev, false);
  numBytes += cIf_init(&cIf_vSzC6vxI, false);
  numBytes += cIf_init(&cIf_KfjFonhP, false);
  numBytes += cIf_init(&cIf_lMdJHevy, false);
  numBytes += cBinop_init(&cBinop_E3HYIId3, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_AvEoztJv, 10.0f);
  numBytes += cPack_init(&cPack_pxohBvYt, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_YNPia1w9, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_wIE5Fgz8, 10.0f);
  numBytes += cPack_init(&cPack_HPq6hEXE, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_45FGNthu, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_tHPRRxRJ, 10.0f);
  numBytes += cPack_init(&cPack_hVVD1gTN, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_FLcpbG6B, 1e-07f);
  numBytes += cIf_init(&cIf_Q5R7NqFe, true);
  numBytes += cVar_init_f(&cVar_EzQRbkTR, 1e-07f);
  numBytes += cVar_init_f(&cVar_sAg4JFoX, 1e-07f);
  numBytes += sVarf_init(&sVarf_a7jZ3cHl, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_SnErxGh9, 0.0f);
  numBytes += cVar_init_f(&cVar_RjNImY8x, 20.0f);
  numBytes += cBinop_init(&cBinop_xvspasRn, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_JfXid9Ov, 0.0f);
  numBytes += cSlice_init(&cSlice_NwC2GKaP, 1, -1);
  numBytes += cSlice_init(&cSlice_VY9OQPD6, 1, -1);
  numBytes += cVar_init_f(&cVar_wvgHfP5M, 0.0f);
  numBytes += cVar_init_f(&cVar_NTcKSi3R, 20.0f);
  numBytes += cVar_init_f(&cVar_i6z0S61P, 0.0f);
  numBytes += cVar_init_f(&cVar_jyAbNz8M, 0.0f);
  numBytes += cVar_init_f(&cVar_NUNwK610, 0.0f);
  numBytes += cSlice_init(&cSlice_t4LrbIWE, 1, 1);
  numBytes += cSlice_init(&cSlice_oXkS7rhk, 0, 1);
  numBytes += cBinop_init(&cBinop_DIcDIV5W, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0bfSxJSg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zj0afviW, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_CZuyEYxf, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_PUxpFJSj, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_ufU1Ytvw, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_cu66nktU, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_vgEAaomI, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_uVBYUxpe, 5.0f);
  numBytes += cVar_init_f(&cVar_HJpvxisd, 500.0f);
  numBytes += cBinop_init(&cBinop_NuxqGD68, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_NBQwbhGt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TPBLFALj, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_uMHzjlHr, 0.0f);
  numBytes += cDelay_init(this, &cDelay_dkPXVKCa, 0.0f);
  numBytes += hTable_init(&hTable_AKL11do1, 256);
  numBytes += cTabhead_init(&cTabhead_DwRmESDF, &hTable_AKL11do1);
  numBytes += cVar_init_s(&cVar_MJaZrkLh, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_tC6zTAkg, 8.0f);
  numBytes += cDelay_init(this, &cDelay_7WnCqrAy, 0.0f);
  numBytes += cBinop_init(&cBinop_McVEtL7Q, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_BO4406nF, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_PD5p0sr0, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_ru4CYo8H, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_HxexI5j7, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_ExI8YtMK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fxWlOheQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w0My1WLt, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwell::~Heavy_vSwell() {
  sEnv_free(&sEnv_wXzEUNGH);
  cPack_free(&cPack_pxohBvYt);
  cPack_free(&cPack_HPq6hEXE);
  cPack_free(&cPack_hVVD1gTN);
  hTable_free(&hTable_AKL11do1);
}

HvTable *Heavy_vSwell::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_AKL11do1; // del-1001-swell
    default: return nullptr;
  }
}

void Heavy_vSwell::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9F1Sr4HJ_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vaczst4p_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IJXJXgsN_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QwaF6Hyy_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_npUeJVWb_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VY9cIO3r_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OHzZEYDT_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uAaba6V7_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qlmDRfk6_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TznG4w7O_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Xxji7vjn_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2vOF9kme_sendMessage);
      break;
    }
    case 0xE7A7BB75: { // Trigger_by_Audio_ON
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T9v6EaBe_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JELN8qLc_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0INr8uMH_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bOZUo5Np_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mr624CXS_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwell::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 30.0f;
        info->maxVal = 85.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_by_Audio_ON";
        info->hash = 0xE7A7BB75;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 13;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwell::sEnv_wXzEUNGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pc1deKhv, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Pc1deKhv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BPKADO7Z, HV_BINOP_LESS_THAN, 0, m, &cBinop_BPKADO7Z_sendMessage);
}

void Heavy_vSwell::cSwitchcase_oi3MNYAo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TTN90JaE, 0, m, &cSlice_TTN90JaE_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZLKIoOsS, 0, m, &cSlice_ZLKIoOsS_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1v74dc8a_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pGkPr3Q5_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_TTN90JaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_whOAjkm5, 0, m, &cVar_whOAjkm5_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_whOAjkm5, 0, m, &cVar_whOAjkm5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_ZLKIoOsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_hlUs0wrQ, HV_BINOP_NEQ, 1, m, &cBinop_hlUs0wrQ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_whOAjkm5, 1, m, &cVar_whOAjkm5_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_hlUs0wrQ, HV_BINOP_NEQ, 1, m, &cBinop_hlUs0wrQ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_whOAjkm5, 1, m, &cVar_whOAjkm5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_whOAjkm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dcE7RUFu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_OR9Z8cOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W9XADzIc_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SatYDuoY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_SatYDuoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_whOAjkm5, 0, m, &cVar_whOAjkm5_sendMessage);
}

void Heavy_vSwell::cCast_W9XADzIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hlUs0wrQ, HV_BINOP_NEQ, 1, m, &cBinop_hlUs0wrQ_sendMessage);
}

void Heavy_vSwell::cBinop_hlUs0wrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OR9Z8cOF, 1, m, &cIf_OR9Z8cOF_sendMessage);
}

void Heavy_vSwell::cCast_pGkPr3Q5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OR9Z8cOF, 0, m, &cIf_OR9Z8cOF_sendMessage);
}

void Heavy_vSwell::cCast_1v74dc8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hlUs0wrQ, HV_BINOP_NEQ, 0, m, &cBinop_hlUs0wrQ_sendMessage);
}

void Heavy_vSwell::cSwitchcase_0MGw2Wlk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aDrhnf2i, 0, m, &cSlice_aDrhnf2i_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Pub8knoH, 0, m, &cSlice_Pub8knoH_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JBiXmYp6_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xDSwgIVr_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_aDrhnf2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_eQwgFqXN, 0, m, &cVar_eQwgFqXN_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_eQwgFqXN, 0, m, &cVar_eQwgFqXN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_Pub8knoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_HcyzZjV5, HV_BINOP_NEQ, 1, m, &cBinop_HcyzZjV5_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_eQwgFqXN, 1, m, &cVar_eQwgFqXN_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_HcyzZjV5, HV_BINOP_NEQ, 1, m, &cBinop_HcyzZjV5_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_eQwgFqXN, 1, m, &cVar_eQwgFqXN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_eQwgFqXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TztX3SrY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_fuRIyBjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OINXRndH_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hYiuf4oJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_hYiuf4oJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eQwgFqXN, 0, m, &cVar_eQwgFqXN_sendMessage);
}

void Heavy_vSwell::cCast_OINXRndH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HcyzZjV5, HV_BINOP_NEQ, 1, m, &cBinop_HcyzZjV5_sendMessage);
}

void Heavy_vSwell::cBinop_HcyzZjV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fuRIyBjN, 1, m, &cIf_fuRIyBjN_sendMessage);
}

void Heavy_vSwell::cCast_JBiXmYp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HcyzZjV5, HV_BINOP_NEQ, 0, m, &cBinop_HcyzZjV5_sendMessage);
}

void Heavy_vSwell::cCast_xDSwgIVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fuRIyBjN, 0, m, &cIf_fuRIyBjN_sendMessage);
}

void Heavy_vSwell::cSwitchcase_dcE7RUFu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3bXkav3j_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3mdB2Aiq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_3bXkav3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5T5FwRlU, 0, m, &cVar_5T5FwRlU_sendMessage);
}

void Heavy_vSwell::cCast_3mdB2Aiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OhurOU94_sendMessage(_c, 0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Q5R7NqFe, 0, m, &cIf_Q5R7NqFe_sendMessage);
}

void Heavy_vSwell::cSwitchcase_TztX3SrY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oMsPG66g_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1AOnikrb_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_oMsPG66g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XUYBC5CW, 0, m, &cVar_XUYBC5CW_sendMessage);
}

void Heavy_vSwell::cCast_1AOnikrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bOhxxFdL_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_XUYBC5CW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pc1deKhv, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Pc1deKhv_sendMessage);
}

void Heavy_vSwell::cVar_5T5FwRlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BPKADO7Z, HV_BINOP_LESS_THAN, 1, m, &cBinop_BPKADO7Z_sendMessage);
}

void Heavy_vSwell::cBinop_Pc1deKhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oi3MNYAo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_BPKADO7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0MGw2Wlk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_OhurOU94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pc1deKhv, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Pc1deKhv_sendMessage);
}

void Heavy_vSwell::cMsg_bOhxxFdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BPKADO7Z, HV_BINOP_LESS_THAN, 1, m, &cBinop_BPKADO7Z_sendMessage);
}

void Heavy_vSwell::cSlice_ug71sBVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ST1ZRaFy_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_jwiqJMut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_KfjFonhP, 0, m, &cIf_KfjFonhP_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_ylqguSev, 0, m, &cIf_ylqguSev_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_Ae9208Ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_lMdJHevy, 0, m, &cIf_lMdJHevy_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_vSzC6vxI, 0, m, &cIf_vSzC6vxI_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_kUCaDqhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eFAJypy3_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VQO1AD81, 0, m, &cIf_VQO1AD81_sendMessage);
}

void Heavy_vSwell::cUnop_ySc5OiEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7lTNu4Cf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E3HYIId3, HV_BINOP_EQ, 1, m, &cBinop_E3HYIId3_sendMessage);
}

void Heavy_vSwell::cUnop_u07xhTEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7lTNu4Cf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E3HYIId3, HV_BINOP_EQ, 1, m, &cBinop_E3HYIId3_sendMessage);
}

void Heavy_vSwell::cIf_VQO1AD81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_u07xhTEN_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_ySc5OiEv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_eFAJypy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VQO1AD81, 1, m, &cIf_VQO1AD81_sendMessage);
}

void Heavy_vSwell::cIf_ylqguSev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QuYVkogS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_vSzC6vxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_KfjFonhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QuYVkogS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_lMdJHevy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_ST1ZRaFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E3HYIId3, HV_BINOP_EQ, 0, m, &cBinop_E3HYIId3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_K0is4VFG_sendMessage);
}

void Heavy_vSwell::cBinop_7lTNu4Cf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pJS49WDd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r1IsDTRO_sendMessage);
}

void Heavy_vSwell::cBinop_E3HYIId3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VyTaX75y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1SchjQQ0_sendMessage);
}

void Heavy_vSwell::cCast_1SchjQQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lMdJHevy, 1, m, &cIf_lMdJHevy_sendMessage);
}

void Heavy_vSwell::cCast_VyTaX75y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ylqguSev, 1, m, &cIf_ylqguSev_sendMessage);
}

void Heavy_vSwell::cCast_r1IsDTRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vSzC6vxI, 1, m, &cIf_vSzC6vxI_sendMessage);
}

void Heavy_vSwell::cCast_pJS49WDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KfjFonhP, 1, m, &cIf_KfjFonhP_sendMessage);
}

void Heavy_vSwell::cBinop_K0is4VFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwell::cSwitchcase_jjFl4mzG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BccbrAQ5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BccbrAQ5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AvEoztJv, 1, m, &cDelay_AvEoztJv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5CXOeXF9_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_AvEoztJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AvEoztJv, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EKzBpoan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pMwiKGYg_sendMessage);
  cSwitchcase_l670qz5t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_BccbrAQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AvEoztJv, 0, m, &cDelay_AvEoztJv_sendMessage);
}

void Heavy_vSwell::cCast_5CXOeXF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AvEoztJv, 0, m, &cDelay_AvEoztJv_sendMessage);
}

void Heavy_vSwell::cPack_pxohBvYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XAQkb6ZT_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_YNPia1w9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_542kqhn4_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_OytSPL42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_jjFl4mzG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_lpQSRMMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_pxohBvYt, 0, m, &cPack_pxohBvYt_sendMessage);
}

void Heavy_vSwell::cCast_vzbHRZGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YNPia1w9, 0, m, &cVar_YNPia1w9_sendMessage);
}

void Heavy_vSwell::cMsg_542kqhn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_jjXeVPrI, 0, m, NULL);
}

void Heavy_vSwell::cMsg_XAQkb6ZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_jjXeVPrI, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_l670qz5t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_msn0ySJv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_msn0ySJv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wIE5Fgz8, 1, m, &cDelay_wIE5Fgz8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KFqJjIO0_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_wIE5Fgz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wIE5Fgz8, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dretmiHT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qLEd5pyy_sendMessage);
  cSwitchcase_WNp6xHGK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_msn0ySJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wIE5Fgz8, 0, m, &cDelay_wIE5Fgz8_sendMessage);
}

void Heavy_vSwell::cCast_KFqJjIO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wIE5Fgz8, 0, m, &cDelay_wIE5Fgz8_sendMessage);
}

void Heavy_vSwell::cPack_HPq6hEXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LUrIZrhT_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_45FGNthu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1RPWbHr2_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_wtyQpQqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_l670qz5t_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_pMwiKGYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_HPq6hEXE, 0, m, &cPack_HPq6hEXE_sendMessage);
}

void Heavy_vSwell::cCast_EKzBpoan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_45FGNthu, 0, m, &cVar_45FGNthu_sendMessage);
}

void Heavy_vSwell::cMsg_1RPWbHr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_jjXeVPrI, 0, m, NULL);
}

void Heavy_vSwell::cMsg_LUrIZrhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_jjXeVPrI, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_WNp6xHGK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tR9tNxT3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tR9tNxT3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tHPRRxRJ, 1, m, &cDelay_tHPRRxRJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0pbgraOJ_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_tHPRRxRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tHPRRxRJ, m);
}

void Heavy_vSwell::cMsg_tR9tNxT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tHPRRxRJ, 0, m, &cDelay_tHPRRxRJ_sendMessage);
}

void Heavy_vSwell::cCast_0pbgraOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tHPRRxRJ, 0, m, &cDelay_tHPRRxRJ_sendMessage);
}

void Heavy_vSwell::cPack_hVVD1gTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TBDqzGsD_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_FLcpbG6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_24z72hbg_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_19QVkfxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_WNp6xHGK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_dretmiHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FLcpbG6B, 0, m, &cVar_FLcpbG6B_sendMessage);
}

void Heavy_vSwell::cCast_qLEd5pyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_hVVD1gTN, 0, m, &cPack_hVVD1gTN_sendMessage);
}

void Heavy_vSwell::cMsg_24z72hbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_jjXeVPrI, 0, m, NULL);
}

void Heavy_vSwell::cMsg_TBDqzGsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_jjXeVPrI, 0, m, NULL);
}

void Heavy_vSwell::cIf_Q5R7NqFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9U0UGWAD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fArvpnzr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSwitchcase_hJaeSqKC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kkLP3meu_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_kkLP3meu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9U0UGWAD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fArvpnzr_sendMessage);
}

void Heavy_vSwell::cVar_EzQRbkTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pFuYq6U3_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_sAg4JFoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_hVVD1gTN, 1, m, &cPack_hVVD1gTN_sendMessage);
}

void Heavy_vSwell::cMsg_rM04sM3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rtfC4GMO_sendMessage);
}

void Heavy_vSwell::cSystem_rtfC4GMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0bfSxJSg, HV_BINOP_MULTIPLY, 1, m, &cBinop_0bfSxJSg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DIcDIV5W, HV_BINOP_MULTIPLY, 1, m, &cBinop_DIcDIV5W_sendMessage);
}

void Heavy_vSwell::cSwitchcase_wDqURdRz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_KRPRtCO6_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_KRPRtCO6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O2R2nQTJ_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_SnErxGh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SnErxGh9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SnErxGh9, 0, m, &cDelay_SnErxGh9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JfXid9Ov, 0, m, &cVar_JfXid9Ov_sendMessage);
}

void Heavy_vSwell::cCast_O2R2nQTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KRPRtCO6_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SnErxGh9, 0, m, &cDelay_SnErxGh9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JfXid9Ov, 0, m, &cVar_JfXid9Ov_sendMessage);
}

void Heavy_vSwell::cMsg_BF9dBAmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_87Grv3tR_sendMessage);
}

void Heavy_vSwell::cSystem_87Grv3tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0FMh9vi3_sendMessage);
}

void Heavy_vSwell::cVar_RjNImY8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xvspasRn, HV_BINOP_MULTIPLY, 0, m, &cBinop_xvspasRn_sendMessage);
}

void Heavy_vSwell::cMsg_KRPRtCO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SnErxGh9, 0, m, &cDelay_SnErxGh9_sendMessage);
}

void Heavy_vSwell::cBinop_XLJUH4nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SnErxGh9, 2, m, &cDelay_SnErxGh9_sendMessage);
}

void Heavy_vSwell::cBinop_0FMh9vi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xvspasRn, HV_BINOP_MULTIPLY, 1, m, &cBinop_xvspasRn_sendMessage);
}

void Heavy_vSwell::cBinop_xvspasRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_XLJUH4nR_sendMessage);
}

void Heavy_vSwell::cVar_JfXid9Ov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zj0afviW, HV_BINOP_SUBTRACT, 0, m, &cBinop_zj0afviW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_eBifJrXq_sendMessage);
}

void Heavy_vSwell::cSwitchcase_Gm1AooMn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rOJxLwIp_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ayBdKFaL_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_rOJxLwIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NUNwK610, 0, m, &cVar_NUNwK610_sendMessage);
}

void Heavy_vSwell::cCast_ayBdKFaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GdfBmMJa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h1gvbvZ0_sendMessage);
}

void Heavy_vSwell::cSwitchcase_7bytgdSt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NwC2GKaP, 0, m, &cSlice_NwC2GKaP_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VY9OQPD6, 0, m, &cSlice_VY9OQPD6_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N1WeSbOG_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_t4LrbIWE, 0, m, &cSlice_t4LrbIWE_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_oXkS7rhk, 0, m, &cSlice_oXkS7rhk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fTKFNBoR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iyJvttWQ_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_NwC2GKaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_hrS7ZuTf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_hrS7ZuTf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_VY9OQPD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2hpK4Pec_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_44lzNrQ0_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2hpK4Pec_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_44lzNrQ0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_wvgHfP5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ybqh93QD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zkRdJ1Jx_sendMessage);
}

void Heavy_vSwell::cVar_NTcKSi3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xmWBo3YI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_xmWBo3YI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zWyYq4uq_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_0bfSxJSg, HV_BINOP_MULTIPLY, 0, m, &cBinop_0bfSxJSg_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_PUxpFJSj, HV_BINOP_DIVIDE, 1, m, &cBinop_PUxpFJSj_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_RjNImY8x, 0, m, &cVar_RjNImY8x_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cCast_zWyYq4uq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7ekG0gON_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_i6z0S61P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vgEAaomI, HV_BINOP_SUBTRACT, 1, m, &cBinop_vgEAaomI_sendMessage);
}

void Heavy_vSwell::cVar_jyAbNz8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NUNwK610, 0, m, &cVar_NUNwK610_sendMessage);
}

void Heavy_vSwell::cVar_NUNwK610_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CZuyEYxf, HV_BINOP_ADD, 0, m, &cBinop_CZuyEYxf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cu66nktU, HV_BINOP_ADD, 0, m, &cBinop_cu66nktU_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_a7jZ3cHl, m);
}

void Heavy_vSwell::cSlice_t4LrbIWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ybqh93QD_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zkRdJ1Jx_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_oXkS7rhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O3YTMN1c_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7SpBq9RK_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_oavhSnPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JfXid9Ov, 1, m, &cVar_JfXid9Ov_sendMessage);
}

void Heavy_vSwell::cBinop_DIcDIV5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_oavhSnPH_sendMessage);
}

void Heavy_vSwell::cBinop_0bfSxJSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_F9qmzD8o_sendMessage);
}

void Heavy_vSwell::cBinop_F9qmzD8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zj0afviW, HV_BINOP_SUBTRACT, 1, m, &cBinop_zj0afviW_sendMessage);
}

void Heavy_vSwell::cBinop_zj0afviW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JfXid9Ov, 1, m, &cVar_JfXid9Ov_sendMessage);
}

void Heavy_vSwell::cMsg_QedTEbHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_wDqURdRz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_IM1IJCFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_wDqURdRz_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cu66nktU, HV_BINOP_ADD, 1, m, &cBinop_cu66nktU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CZuyEYxf, HV_BINOP_ADD, 1, m, &cBinop_CZuyEYxf_sendMessage);
}

void Heavy_vSwell::cBinop_eBifJrXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Gm1AooMn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_CZuyEYxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NUNwK610, 1, m, &cVar_NUNwK610_sendMessage);
}

void Heavy_vSwell::cBinop_PUxpFJSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ufU1Ytvw, HV_BINOP_DIVIDE, 1, m, &cBinop_ufU1Ytvw_sendMessage);
}

void Heavy_vSwell::cBinop_ufU1Ytvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cu66nktU, HV_BINOP_ADD, 1, m, &cBinop_cu66nktU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CZuyEYxf, HV_BINOP_ADD, 1, m, &cBinop_CZuyEYxf_sendMessage);
}

void Heavy_vSwell::cCast_zkRdJ1Jx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PUxpFJSj, HV_BINOP_DIVIDE, 0, m, &cBinop_PUxpFJSj_sendMessage);
}

void Heavy_vSwell::cCast_ybqh93QD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DIcDIV5W, HV_BINOP_MULTIPLY, 0, m, &cBinop_DIcDIV5W_sendMessage);
}

void Heavy_vSwell::cCast_7SpBq9RK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vgEAaomI, HV_BINOP_SUBTRACT, 0, m, &cBinop_vgEAaomI_sendMessage);
}

void Heavy_vSwell::cCast_O3YTMN1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jyAbNz8M, 1, m, &cVar_jyAbNz8M_sendMessage);
}

void Heavy_vSwell::cCast_h1gvbvZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jyAbNz8M, 0, m, &cVar_jyAbNz8M_sendMessage);
}

void Heavy_vSwell::cCast_GdfBmMJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IM1IJCFH_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_cu66nktU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i6z0S61P, 0, m, &cVar_i6z0S61P_sendMessage);
}

void Heavy_vSwell::cMsg_hrS7ZuTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_wDqURdRz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_tlcf1X4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_wvgHfP5M, 1, m, &cVar_wvgHfP5M_sendMessage);
}

void Heavy_vSwell::cMsg_7ekG0gON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0bfSxJSg, HV_BINOP_MULTIPLY, 0, m, &cBinop_0bfSxJSg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PUxpFJSj, HV_BINOP_DIVIDE, 1, m, &cBinop_PUxpFJSj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RjNImY8x, 0, m, &cVar_RjNImY8x_sendMessage);
}

void Heavy_vSwell::cCast_44lzNrQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kfRdfZ9d_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cu66nktU, HV_BINOP_ADD, 0, m, &cBinop_cu66nktU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NUNwK610, 1, m, &cVar_NUNwK610_sendMessage);
}

void Heavy_vSwell::cCast_2hpK4Pec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hrS7ZuTf_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_vgEAaomI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ufU1Ytvw, HV_BINOP_DIVIDE, 0, m, &cBinop_ufU1Ytvw_sendMessage);
}

void Heavy_vSwell::cCast_kfRdfZ9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IM1IJCFH_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_fTKFNBoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QedTEbHq_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_iyJvttWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tlcf1X4c_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_N1WeSbOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wvgHfP5M, 0, m, &cVar_wvgHfP5M_sendMessage);
}

void Heavy_vSwell::cSwitchcase_z4w4gU2s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mQUqUoRM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mQUqUoRM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uVBYUxpe, 1, m, &cDelay_uVBYUxpe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VlkDOgyL_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_uVBYUxpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uVBYUxpe, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vzbHRZGm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lpQSRMMj_sendMessage);
  cSwitchcase_jjFl4mzG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_mQUqUoRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uVBYUxpe, 0, m, &cDelay_uVBYUxpe_sendMessage);
}

void Heavy_vSwell::cCast_VlkDOgyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uVBYUxpe, 0, m, &cDelay_uVBYUxpe_sendMessage);
}

void Heavy_vSwell::cVar_HJpvxisd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NuxqGD68, HV_BINOP_MULTIPLY, 0, m, &cBinop_NuxqGD68_sendMessage);
}

void Heavy_vSwell::cMsg_MRo2gPxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ie4szoCW_sendMessage);
}

void Heavy_vSwell::cSystem_ie4szoCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rZ7LA4Au_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_NuxqGD68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YR4E8G4T_sendMessage);
}

void Heavy_vSwell::cBinop_qMd0gNdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NuxqGD68, HV_BINOP_MULTIPLY, 1, m, &cBinop_NuxqGD68_sendMessage);
}

void Heavy_vSwell::cMsg_rZ7LA4Au_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qMd0gNdF_sendMessage);
}

void Heavy_vSwell::cBinop_YR4E8G4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_PvNWiDo2_sendMessage);
}

void Heavy_vSwell::cBinop_PvNWiDo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_09uTTqLw_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_TPBLFALj, m);
}

void Heavy_vSwell::cBinop_09uTTqLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_NBQwbhGt, m);
}

void Heavy_vSwell::cMsg_Ptx0Ddmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kiCpEZIS_sendMessage);
}

void Heavy_vSwell::cSystem_kiCpEZIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bLcznCxK_sendMessage);
}

void Heavy_vSwell::cDelay_uMHzjlHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uMHzjlHr, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_dkPXVKCa, 0, m, &cDelay_dkPXVKCa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uMHzjlHr, 0, m, &cDelay_uMHzjlHr_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4iycDuug, 1, m, NULL);
}

void Heavy_vSwell::cDelay_dkPXVKCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dkPXVKCa, m);
  cMsg_pLwXlPQ6_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_A5x4mTfq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_g2t40sWt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cBinop_W5tnN1Yx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eyQDtaJg_sendMessage(_c, 0, m);
}

void Heavy_vSwell::hTable_AKL11do1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IJTeyVIv_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uMHzjlHr, 2, m, &cDelay_uMHzjlHr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Z101VzKi_sendMessage);
}

void Heavy_vSwell::cMsg_eyQDtaJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_AKL11do1, 0, m, &hTable_AKL11do1_sendMessage);
}

void Heavy_vSwell::cBinop_bLcznCxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_W5tnN1Yx_sendMessage);
}

void Heavy_vSwell::cMsg_pLwXlPQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_AKL11do1, 0, m, &hTable_AKL11do1_sendMessage);
}

void Heavy_vSwell::cCast_Z101VzKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uMHzjlHr, 0, m, &cDelay_uMHzjlHr_sendMessage);
}

void Heavy_vSwell::cMsg_IJTeyVIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_dkPXVKCa, 2, m, &cDelay_dkPXVKCa_sendMessage);
}

void Heavy_vSwell::cMsg_g2t40sWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4iycDuug, 1, m, NULL);
}

void Heavy_vSwell::cTabhead_DwRmESDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BO4406nF, HV_BINOP_SUBTRACT, 0, m, &cBinop_BO4406nF_sendMessage);
}

void Heavy_vSwell::cMsg_tCDkKI08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_epye4I3t_sendMessage);
}

void Heavy_vSwell::cSystem_epye4I3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RKfyrNIJ_sendMessage);
}

void Heavy_vSwell::cVar_MJaZrkLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pH9WBGHW_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cDelay_tC6zTAkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tC6zTAkg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7WnCqrAy, 0, m, &cDelay_7WnCqrAy_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_N9Hq4bK9, 0, m, &sTabread_N9Hq4bK9_sendMessage);
}

void Heavy_vSwell::cDelay_7WnCqrAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7WnCqrAy, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_N9Hq4bK9, 0, m, &sTabread_N9Hq4bK9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7WnCqrAy, 0, m, &cDelay_7WnCqrAy_sendMessage);
}

void Heavy_vSwell::sTabread_N9Hq4bK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ru4CYo8H, HV_BINOP_SUBTRACT, 0, m, &cBinop_ru4CYo8H_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_McVEtL7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PD5p0sr0, HV_BINOP_MAX, 0, m, &cBinop_PD5p0sr0_sendMessage);
}

void Heavy_vSwell::cBinop_RKfyrNIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_McVEtL7Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_McVEtL7Q_sendMessage);
}

void Heavy_vSwell::cBinop_BO4406nF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AVghTeaA_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_N9Hq4bK9, 0, m, &sTabread_N9Hq4bK9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_99N7cON7_sendMessage);
}

void Heavy_vSwell::cSystem_03ZUUnP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ru4CYo8H, HV_BINOP_SUBTRACT, 1, m, &cBinop_ru4CYo8H_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7WnCqrAy, 2, m, &cDelay_7WnCqrAy_sendMessage);
}

void Heavy_vSwell::cMsg_pH9WBGHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_03ZUUnP8_sendMessage);
}

void Heavy_vSwell::cMsg_AVghTeaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tC6zTAkg, 0, m, &cDelay_tC6zTAkg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7WnCqrAy, 0, m, &cDelay_7WnCqrAy_sendMessage);
}

void Heavy_vSwell::cMsg_8kizvdCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_PD5p0sr0, HV_BINOP_MAX, 1, m, &cBinop_PD5p0sr0_sendMessage);
}

void Heavy_vSwell::cBinop_PD5p0sr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BO4406nF, HV_BINOP_SUBTRACT, 1, m, &cBinop_BO4406nF_sendMessage);
}

void Heavy_vSwell::cCast_99N7cON7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tC6zTAkg, 0, m, &cDelay_tC6zTAkg_sendMessage);
}

void Heavy_vSwell::cBinop_BYSEWSdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tC6zTAkg, 2, m, &cDelay_tC6zTAkg_sendMessage);
}

void Heavy_vSwell::cBinop_ru4CYo8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BYSEWSdQ_sendMessage);
}

void Heavy_vSwell::cCast_ls6VasVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MJaZrkLh, 0, m, &cVar_MJaZrkLh_sendMessage);
  cMsg_tCDkKI08_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_DwRmESDF, 0, m, &cTabhead_DwRmESDF_sendMessage);
}

void Heavy_vSwell::cUnop_umnuzqvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fxWlOheQ, m);
}

void Heavy_vSwell::cCast_fArvpnzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_z4w4gU2s_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_9U0UGWAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eUbv4ggU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EzQRbkTR, 0, m, &cVar_EzQRbkTR_sendMessage);
}

void Heavy_vSwell::cCast_ifwmPGyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HxexI5j7, HV_BINOP_SUBTRACT, 0, m, &cBinop_HxexI5j7_sendMessage);
}

void Heavy_vSwell::cCast_LAgYjSMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XUYBC5CW, 0, m, &cVar_XUYBC5CW_sendMessage);
}

void Heavy_vSwell::cBinop_HxexI5j7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5T5FwRlU, 0, m, &cVar_5T5FwRlU_sendMessage);
}

void Heavy_vSwell::cSend_eUbv4ggU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bOZUo5Np_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_QuYVkogS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hJaeSqKC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_HJldY6h1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_7bytgdSt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_pFuYq6U3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jjXeVPrI, 0, m, NULL);
}

void Heavy_vSwell::cSend_dW9Tz6ff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mr624CXS_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_cExvRcDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uVBYUxpe, 1, m, &cDelay_uVBYUxpe_sendMessage);
}

void Heavy_vSwell::cBinop_YBz63tS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_umnuzqvS_sendMessage);
}

void Heavy_vSwell::cReceive_qlmDRfk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HxexI5j7, HV_BINOP_SUBTRACT, 1, m, &cBinop_HxexI5j7_sendMessage);
}

void Heavy_vSwell::cReceive_JELN8qLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BF9dBAmb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RjNImY8x, 0, m, &cVar_RjNImY8x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kUCaDqhr, 0, m, &cVar_kUCaDqhr_sendMessage);
  cMsg_rM04sM3w_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_i6z0S61P, 0, m, &cVar_i6z0S61P_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NTcKSi3R, 0, m, &cVar_NTcKSi3R_sendMessage);
  cMsg_MRo2gPxY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HJpvxisd, 0, m, &cVar_HJpvxisd_sendMessage);
  cMsg_Ptx0Ddmx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sAg4JFoX, 0, m, &cVar_sAg4JFoX_sendMessage);
  cMsg_8kizvdCC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MJaZrkLh, 0, m, &cVar_MJaZrkLh_sendMessage);
  cMsg_tCDkKI08_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_DwRmESDF, 0, m, &cTabhead_DwRmESDF_sendMessage);
}

void Heavy_vSwell::cReceive_0INr8uMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_ug71sBVZ, 0, m, &cSlice_ug71sBVZ_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_jwiqJMut, 0, m, &cSlice_jwiqJMut_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_Ae9208Ic, 0, m, &cSlice_Ae9208Ic_sendMessage);
}

void Heavy_vSwell::cReceive_VY9cIO3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ExI8YtMK, m);
}

void Heavy_vSwell::cReceive_bOZUo5Np_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OytSPL42_sendMessage(_c, 0, m);
  cMsg_wtyQpQqN_sendMessage(_c, 0, m);
  cMsg_19QVkfxw_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_uAaba6V7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ifwmPGyW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LAgYjSMs_sendMessage);
}

void Heavy_vSwell::cReceive_2vOF9kme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9U0UGWAD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fArvpnzr_sendMessage);
}

void Heavy_vSwell::cReceive_T9v6EaBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q5R7NqFe, 1, m, &cIf_Q5R7NqFe_sendMessage);
}

void Heavy_vSwell::cReceive_9F1Sr4HJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_45FGNthu, 1, m, &cVar_45FGNthu_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_pxohBvYt, 1, m, &cPack_pxohBvYt_sendMessage);
}

void Heavy_vSwell::cReceive_Vaczst4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_pxohBvYt, 2, m, &cPack_pxohBvYt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AvEoztJv, 1, m, &cDelay_AvEoztJv_sendMessage);
}

void Heavy_vSwell::cReceive_IJXJXgsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_HPq6hEXE, 1, m, &cPack_HPq6hEXE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FLcpbG6B, 1, m, &cVar_FLcpbG6B_sendMessage);
}

void Heavy_vSwell::cReceive_QwaF6Hyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_HPq6hEXE, 2, m, &cPack_HPq6hEXE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wIE5Fgz8, 1, m, &cDelay_wIE5Fgz8_sendMessage);
}

void Heavy_vSwell::cReceive_npUeJVWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_hVVD1gTN, 2, m, &cPack_hVVD1gTN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tHPRRxRJ, 1, m, &cDelay_tHPRRxRJ_sendMessage);
}

void Heavy_vSwell::cReceive_mr624CXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sAg4JFoX, 1, m, &cVar_sAg4JFoX_sendMessage);
  cMsg_HJldY6h1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EzQRbkTR, 1, m, &cVar_EzQRbkTR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YNPia1w9, 1, m, &cVar_YNPia1w9_sendMessage);
}

void Heavy_vSwell::cReceive_OHzZEYDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dW9Tz6ff_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_Xxji7vjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_cExvRcDh_sendMessage);
}

void Heavy_vSwell::cReceive_TznG4w7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_YBz63tS3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_w0My1WLt, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwell::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4;

  // input and output vars
  hv_bufferf_t O0;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_4iycDuug, VIf(I0));
    __hv_tabread_f(&sTabread_N9Hq4bK9, VOf(Bf0));
    __hv_varread_f(&sVarf_TPBLFALj, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_NBQwbhGt, VOf(Bf2));
    __hv_rpole_f(&sRPole_jAGTEifB, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_w0My1WLt, VOf(Bf1));
    __hv_varread_f(&sVarf_fxWlOheQ, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf3));
    __hv_gt_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_sqrt_f(VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_wXzEUNGH, VIf(Bf3), &sEnv_wXzEUNGH_sendMessage);
    __hv_line_f(&sLine_jjXeVPrI, VOf(Bf3));
    __hv_varread_f(&sVarf_ExI8YtMK, VOf(Bf1));
    __hv_pow_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_a7jZ3cHl, VOf(Bf3));
    __hv_max_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwell::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 1 channel(s)
  float **const bOut = &outputBuffers;

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwell::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 1 channel(s)
  float *const bOut = outputBuffers;

  int n = processInline(bIn, bOut, n4);

  

  return n;
}
