/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELL_HPP_
#define _HEAVY_CONTEXT_VSWELL_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlBinop.h"
#include "HvControlPack.h"
#include "HvSignalTabwrite.h"
#include "HvSignalTabread.h"
#include "HvControlSlice.h"
#include "HvControlVar.h"
#include "HvSignalVar.h"
#include "HvSignalEnvelope.h"
#include "HvMath.h"
#include "HvControlIf.h"
#include "HvSignalDel1.h"
#include "HvControlSystem.h"
#include "HvControlDelay.h"
#include "HvSignalRPole.h"
#include "HvControlCast.h"
#include "HvSignalLine.h"
#include "HvTable.h"
#include "HvControlUnop.h"
#include "HvControlTabhead.h"

class Heavy_vSwell : public HeavyContext {

 public:
  Heavy_vSwell(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwell();

  const char *getName() override { return "vSwell"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 1; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_BY_AUDIO_ON = 0xE7A7BB75, // Trigger_by_Audio_ON
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_wXzEUNGH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oi3MNYAo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_TTN90JaE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_ZLKIoOsS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_whOAjkm5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OR9Z8cOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SatYDuoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W9XADzIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hlUs0wrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pGkPr3Q5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1v74dc8a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0MGw2Wlk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_aDrhnf2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_Pub8knoH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eQwgFqXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fuRIyBjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hYiuf4oJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OINXRndH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HcyzZjV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JBiXmYp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xDSwgIVr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dcE7RUFu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_3bXkav3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3mdB2Aiq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TztX3SrY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_oMsPG66g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1AOnikrb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XUYBC5CW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5T5FwRlU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pc1deKhv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BPKADO7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OhurOU94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bOhxxFdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_ug71sBVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_jwiqJMut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_Ae9208Ic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kUCaDqhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ySc5OiEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_u07xhTEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_VQO1AD81_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eFAJypy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ylqguSev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vSzC6vxI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KfjFonhP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lMdJHevy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ST1ZRaFy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7lTNu4Cf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E3HYIId3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1SchjQQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VyTaX75y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r1IsDTRO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pJS49WDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K0is4VFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jjFl4mzG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_AvEoztJv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BccbrAQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5CXOeXF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_pxohBvYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YNPia1w9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OytSPL42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lpQSRMMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vzbHRZGm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_542kqhn4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XAQkb6ZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_l670qz5t_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wIE5Fgz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_msn0ySJv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KFqJjIO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_HPq6hEXE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_45FGNthu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wtyQpQqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pMwiKGYg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EKzBpoan_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1RPWbHr2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LUrIZrhT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WNp6xHGK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_tHPRRxRJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tR9tNxT3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0pbgraOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_hVVD1gTN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FLcpbG6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_19QVkfxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dretmiHT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qLEd5pyy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_24z72hbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TBDqzGsD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Q5R7NqFe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hJaeSqKC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_kkLP3meu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EzQRbkTR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sAg4JFoX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rM04sM3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rtfC4GMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wDqURdRz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_SnErxGh9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O2R2nQTJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BF9dBAmb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_87Grv3tR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RjNImY8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KRPRtCO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XLJUH4nR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0FMh9vi3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xvspasRn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JfXid9Ov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Gm1AooMn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_rOJxLwIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ayBdKFaL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7bytgdSt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_NwC2GKaP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_VY9OQPD6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wvgHfP5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NTcKSi3R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xmWBo3YI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_zWyYq4uq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_i6z0S61P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jyAbNz8M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NUNwK610_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_t4LrbIWE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_oXkS7rhk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oavhSnPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DIcDIV5W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0bfSxJSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F9qmzD8o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zj0afviW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QedTEbHq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IM1IJCFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eBifJrXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CZuyEYxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PUxpFJSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ufU1Ytvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zkRdJ1Jx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ybqh93QD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7SpBq9RK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O3YTMN1c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h1gvbvZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GdfBmMJa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cu66nktU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hrS7ZuTf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tlcf1X4c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7ekG0gON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_44lzNrQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2hpK4Pec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vgEAaomI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kfRdfZ9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fTKFNBoR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iyJvttWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N1WeSbOG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_z4w4gU2s_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_uVBYUxpe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mQUqUoRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VlkDOgyL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HJpvxisd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MRo2gPxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ie4szoCW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NuxqGD68_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qMd0gNdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rZ7LA4Au_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YR4E8G4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PvNWiDo2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_09uTTqLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ptx0Ddmx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kiCpEZIS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_uMHzjlHr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dkPXVKCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_A5x4mTfq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_W5tnN1Yx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_AKL11do1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eyQDtaJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bLcznCxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pLwXlPQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z101VzKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IJTeyVIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g2t40sWt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_DwRmESDF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tCDkKI08_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_epye4I3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MJaZrkLh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_tC6zTAkg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_7WnCqrAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_N9Hq4bK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_McVEtL7Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RKfyrNIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BO4406nF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_03ZUUnP8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pH9WBGHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AVghTeaA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8kizvdCC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PD5p0sr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_99N7cON7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BYSEWSdQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ru4CYo8H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ls6VasVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_umnuzqvS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fArvpnzr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9U0UGWAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ifwmPGyW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LAgYjSMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HxexI5j7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_eUbv4ggU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QuYVkogS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HJldY6h1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pFuYq6U3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dW9Tz6ff_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cExvRcDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YBz63tS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qlmDRfk6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JELN8qLc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0INr8uMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VY9cIO3r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bOZUo5Np_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uAaba6V7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2vOF9kme_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_T9v6EaBe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9F1Sr4HJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Vaczst4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IJXJXgsN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QwaF6Hyy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_npUeJVWb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mr624CXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OHzZEYDT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Xxji7vjn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TznG4w7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_4iycDuug;
  SignalTabread sTabread_N9Hq4bK9;
  SignalRPole sRPole_jAGTEifB;
  SignalEnvelope sEnv_wXzEUNGH;
  SignalLine sLine_jjXeVPrI;
  ControlSlice cSlice_TTN90JaE;
  ControlSlice cSlice_ZLKIoOsS;
  ControlVar cVar_whOAjkm5;
  ControlIf cIf_OR9Z8cOF;
  ControlBinop cBinop_hlUs0wrQ;
  ControlSlice cSlice_aDrhnf2i;
  ControlSlice cSlice_Pub8knoH;
  ControlVar cVar_eQwgFqXN;
  ControlIf cIf_fuRIyBjN;
  ControlBinop cBinop_HcyzZjV5;
  ControlVar cVar_XUYBC5CW;
  ControlVar cVar_5T5FwRlU;
  ControlBinop cBinop_Pc1deKhv;
  ControlBinop cBinop_BPKADO7Z;
  ControlSlice cSlice_ug71sBVZ;
  ControlSlice cSlice_jwiqJMut;
  ControlSlice cSlice_Ae9208Ic;
  ControlVar cVar_kUCaDqhr;
  ControlIf cIf_VQO1AD81;
  ControlBinop cBinop_eFAJypy3;
  ControlIf cIf_ylqguSev;
  ControlIf cIf_vSzC6vxI;
  ControlIf cIf_KfjFonhP;
  ControlIf cIf_lMdJHevy;
  ControlBinop cBinop_ST1ZRaFy;
  ControlBinop cBinop_7lTNu4Cf;
  ControlBinop cBinop_E3HYIId3;
  ControlBinop cBinop_K0is4VFG;
  ControlDelay cDelay_AvEoztJv;
  ControlPack cPack_pxohBvYt;
  ControlVar cVar_YNPia1w9;
  ControlDelay cDelay_wIE5Fgz8;
  ControlPack cPack_HPq6hEXE;
  ControlVar cVar_45FGNthu;
  ControlDelay cDelay_tHPRRxRJ;
  ControlPack cPack_hVVD1gTN;
  ControlVar cVar_FLcpbG6B;
  ControlIf cIf_Q5R7NqFe;
  ControlVar cVar_EzQRbkTR;
  ControlVar cVar_sAg4JFoX;
  SignalVarf sVarf_a7jZ3cHl;
  ControlDelay cDelay_SnErxGh9;
  ControlVar cVar_RjNImY8x;
  ControlBinop cBinop_XLJUH4nR;
  ControlBinop cBinop_0FMh9vi3;
  ControlBinop cBinop_xvspasRn;
  ControlVar cVar_JfXid9Ov;
  ControlSlice cSlice_NwC2GKaP;
  ControlSlice cSlice_VY9OQPD6;
  ControlVar cVar_wvgHfP5M;
  ControlVar cVar_NTcKSi3R;
  ControlVar cVar_i6z0S61P;
  ControlVar cVar_jyAbNz8M;
  ControlVar cVar_NUNwK610;
  ControlSlice cSlice_t4LrbIWE;
  ControlSlice cSlice_oXkS7rhk;
  ControlBinop cBinop_oavhSnPH;
  ControlBinop cBinop_DIcDIV5W;
  ControlBinop cBinop_0bfSxJSg;
  ControlBinop cBinop_F9qmzD8o;
  ControlBinop cBinop_zj0afviW;
  ControlBinop cBinop_eBifJrXq;
  ControlBinop cBinop_CZuyEYxf;
  ControlBinop cBinop_PUxpFJSj;
  ControlBinop cBinop_ufU1Ytvw;
  ControlBinop cBinop_cu66nktU;
  ControlBinop cBinop_vgEAaomI;
  ControlDelay cDelay_uVBYUxpe;
  ControlVar cVar_HJpvxisd;
  ControlBinop cBinop_NuxqGD68;
  ControlBinop cBinop_qMd0gNdF;
  SignalVarf sVarf_NBQwbhGt;
  ControlBinop cBinop_YR4E8G4T;
  ControlBinop cBinop_PvNWiDo2;
  ControlBinop cBinop_09uTTqLw;
  SignalVarf sVarf_TPBLFALj;
  ControlDelay cDelay_uMHzjlHr;
  ControlDelay cDelay_dkPXVKCa;
  ControlBinop cBinop_W5tnN1Yx;
  HvTable hTable_AKL11do1;
  ControlBinop cBinop_bLcznCxK;
  ControlTabhead cTabhead_DwRmESDF;
  ControlVar cVar_MJaZrkLh;
  ControlDelay cDelay_tC6zTAkg;
  ControlDelay cDelay_7WnCqrAy;
  ControlBinop cBinop_McVEtL7Q;
  ControlBinop cBinop_RKfyrNIJ;
  ControlBinop cBinop_BO4406nF;
  ControlBinop cBinop_PD5p0sr0;
  ControlBinop cBinop_BYSEWSdQ;
  ControlBinop cBinop_ru4CYo8H;
  ControlBinop cBinop_HxexI5j7;
  ControlBinop cBinop_QuYVkogS;
  ControlBinop cBinop_cExvRcDh;
  ControlBinop cBinop_YBz63tS3;
  SignalVarf sVarf_ExI8YtMK;
  SignalVarf sVarf_fxWlOheQ;
  SignalVarf sVarf_w0My1WLt;
};

#endif // _HEAVY_CONTEXT_VSWELL_HPP_
