/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwellST.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwellST *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwellST_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwellST_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwellST();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwellST::Heavy_vSwellST(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_UqKEJw0T, &hTable_KeIb71kI);
  numBytes += sTabwrite_init(&sTabwrite_NxqJoUBI, &hTable_jcPFd4Xr);
  numBytes += sRPole_init(&sRPole_gvIYpzzE);
  numBytes += sEnv_init(&sEnv_34b7UgwQ, 1024, 512);
  numBytes += sTabread_init(&sTabread_01ojBHIV, &hTable_jcPFd4Xr, true);
  numBytes += sLine_init(&sLine_2F3wGoZo);
  numBytes += sTabread_init(&sTabread_a9gDhwTu, &hTable_KeIb71kI, true);
  numBytes += cSlice_init(&cSlice_g0Z90FPE, 1, -1);
  numBytes += cSlice_init(&cSlice_CNPmDsD4, 1, -1);
  numBytes += cVar_init_f(&cVar_1uotDkCA, 0.0f);
  numBytes += cIf_init(&cIf_eY4Jvawl, false);
  numBytes += cBinop_init(&cBinop_XhwalkxR, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_D32LADbA, 1, -1);
  numBytes += cSlice_init(&cSlice_uYjiDyPt, 1, -1);
  numBytes += cVar_init_f(&cVar_JMf04BBO, 0.0f);
  numBytes += cIf_init(&cIf_EqwhxC9k, false);
  numBytes += cBinop_init(&cBinop_HsnYSF6n, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_dBS2mylK, 0.0f);
  numBytes += cVar_init_f(&cVar_13wH22rG, 0.0f);
  numBytes += cBinop_init(&cBinop_eDJZONPa, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_klXYaPdt, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_PFrs5tGq, 2, 1);
  numBytes += cSlice_init(&cSlice_9tMY4GIr, 1, 1);
  numBytes += cSlice_init(&cSlice_QRrpO2Zt, 0, 1);
  numBytes += cVar_init_f(&cVar_1XT4XiBN, 0.0f);
  numBytes += cIf_init(&cIf_Sl4FfOD6, false);
  numBytes += cIf_init(&cIf_3Zl5RvPP, false);
  numBytes += cIf_init(&cIf_dC7e2fnY, false);
  numBytes += cIf_init(&cIf_O44xwAnh, false);
  numBytes += cIf_init(&cIf_oxsV0dKU, false);
  numBytes += cBinop_init(&cBinop_CvpK1ifn, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_Rr7uKltH, 10.0f);
  numBytes += cPack_init(&cPack_Ym8EIEEj, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_LV0pggu3, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_5qQai8Y6, 10.0f);
  numBytes += cPack_init(&cPack_3laRlUTP, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_bR01cUrC, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_7C6CZmSe, 10.0f);
  numBytes += cPack_init(&cPack_mxWDXeLC, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_O2IKjTxU, 1e-07f);
  numBytes += cVar_init_f(&cVar_kdAJQpXS, 1e-07f);
  numBytes += cVar_init_f(&cVar_OPyjHWHy, 1e-07f);
  numBytes += sVarf_init(&sVarf_ovpS4sT3, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_sQwZUAOI, 0.0f);
  numBytes += cVar_init_f(&cVar_2x57PHa6, 20.0f);
  numBytes += cBinop_init(&cBinop_KPvwJmbF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_UKdKTjZD, 0.0f);
  numBytes += cSlice_init(&cSlice_3k3vZn5N, 1, -1);
  numBytes += cSlice_init(&cSlice_5i3XKb89, 1, -1);
  numBytes += cVar_init_f(&cVar_ljKlyqMS, 0.0f);
  numBytes += cVar_init_f(&cVar_deu2nYAm, 20.0f);
  numBytes += cVar_init_f(&cVar_pbmPnpEI, 0.0f);
  numBytes += cVar_init_f(&cVar_88xreAl7, 0.0f);
  numBytes += cVar_init_f(&cVar_U8MQNAKf, 0.0f);
  numBytes += cSlice_init(&cSlice_WLrs0mAP, 1, 1);
  numBytes += cSlice_init(&cSlice_4yceTXNW, 0, 1);
  numBytes += cBinop_init(&cBinop_bGCjGErh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_M29omxKv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jrCTdQJr, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_rQ5Apeh0, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Vbtd0YDf, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_iBtwHNaH, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_AGhiX020, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_xEQ1yD3O, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_UGOjvSxE, 5.0f);
  numBytes += cVar_init_f(&cVar_w3c8OBdy, 500.0f);
  numBytes += cBinop_init(&cBinop_nA1LAYvr, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_R3kDg9RB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FqGhPqsg, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_j8713VtR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_TuE6pYu0, 0.0f);
  numBytes += hTable_init(&hTable_KeIb71kI, 256);
  numBytes += cTabhead_init(&cTabhead_xRbaUNfD, &hTable_KeIb71kI);
  numBytes += cVar_init_s(&cVar_xXWaOh7e, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_OkbGSi79, 8.0f);
  numBytes += cDelay_init(this, &cDelay_ddmKtAAO, 0.0f);
  numBytes += cBinop_init(&cBinop_iZjcIvYi, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_981wIgUy, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_IuWJY2Gy, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_J8eeRZAz, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_RukeXTUF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_LxNvlnJr, 0.0f);
  numBytes += hTable_init(&hTable_jcPFd4Xr, 256);
  numBytes += cTabhead_init(&cTabhead_iHeYTSPk, &hTable_jcPFd4Xr);
  numBytes += cVar_init_s(&cVar_ipL3gcF9, "del-1001-swell2");
  numBytes += cDelay_init(this, &cDelay_pqzSOeGx, 8.0f);
  numBytes += cDelay_init(this, &cDelay_hsHAbhCV, 0.0f);
  numBytes += cBinop_init(&cBinop_JSLDdQ7K, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_yQJukM5Z, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_JBlmzsBO, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_5Q7CSrTr, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_jZYzRI8K, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_Mh9Ly15k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MKdxfRU6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ghed3sZ9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SXGVRNNH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V1ESP7TQ, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwellST::~Heavy_vSwellST() {
  sEnv_free(&sEnv_34b7UgwQ);
  cPack_free(&cPack_Ym8EIEEj);
  cPack_free(&cPack_3laRlUTP);
  cPack_free(&cPack_mxWDXeLC);
  hTable_free(&hTable_KeIb71kI);
  hTable_free(&hTable_jcPFd4Xr);
}

HvTable *Heavy_vSwellST::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_KeIb71kI; // del-1001-swell
    case 0x505A9C79: return &hTable_jcPFd4Xr; // del-1001-swell2
    default: return nullptr;
  }
}

void Heavy_vSwellST::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nQtTx3zZ_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EMoLMfNw_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CmisqW5V_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gu2uh9Ur_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZS6Y4MAt_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v0387Lgi_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xvzTp40z_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xJp9d5IM_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_08sCoVZ6_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NhXVCGsR_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QL0Ce7n6_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J5TQeArv_sendMessage);
      break;
    }
    case 0x4E6E7C40: { // Trigger_Left
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HUGDIaT1_sendMessage);
      break;
    }
    case 0xB181ABB6: { // Trigger_Right
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iDKZyzga_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V9dxL51G_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UghqXrFc_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RCVF8VlO_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IkMyKmNk_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwellST::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 20.0f;
        info->maxVal = 90.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_Left";
        info->hash = 0x4E6E7C40;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "Trigger_Right";
        info->hash = 0xB181ABB6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 14;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwellST::sEnv_34b7UgwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eDJZONPa, HV_BINOP_GREATER_THAN, 0, m, &cBinop_eDJZONPa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_klXYaPdt, HV_BINOP_LESS_THAN, 0, m, &cBinop_klXYaPdt_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_5uFVj4qs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_g0Z90FPE, 0, m, &cSlice_g0Z90FPE_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CNPmDsD4, 0, m, &cSlice_CNPmDsD4_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6GKLy317_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uyL4q6TK_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_g0Z90FPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_1uotDkCA, 0, m, &cVar_1uotDkCA_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_1uotDkCA, 0, m, &cVar_1uotDkCA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_CNPmDsD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XhwalkxR, HV_BINOP_NEQ, 1, m, &cBinop_XhwalkxR_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_1uotDkCA, 1, m, &cVar_1uotDkCA_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XhwalkxR, HV_BINOP_NEQ, 1, m, &cBinop_XhwalkxR_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_1uotDkCA, 1, m, &cVar_1uotDkCA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_1uotDkCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Cvbib7Ns_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_eY4Jvawl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_66nyDXdI_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MVSukJ50_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_MVSukJ50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1uotDkCA, 0, m, &cVar_1uotDkCA_sendMessage);
}

void Heavy_vSwellST::cCast_66nyDXdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XhwalkxR, HV_BINOP_NEQ, 1, m, &cBinop_XhwalkxR_sendMessage);
}

void Heavy_vSwellST::cBinop_XhwalkxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eY4Jvawl, 1, m, &cIf_eY4Jvawl_sendMessage);
}

void Heavy_vSwellST::cCast_uyL4q6TK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eY4Jvawl, 0, m, &cIf_eY4Jvawl_sendMessage);
}

void Heavy_vSwellST::cCast_6GKLy317_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XhwalkxR, HV_BINOP_NEQ, 0, m, &cBinop_XhwalkxR_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_voSfg638_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_D32LADbA, 0, m, &cSlice_D32LADbA_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uYjiDyPt, 0, m, &cSlice_uYjiDyPt_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o6HATbE4_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6uxWWPKe_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_D32LADbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_JMf04BBO, 0, m, &cVar_JMf04BBO_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_JMf04BBO, 0, m, &cVar_JMf04BBO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_uYjiDyPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_HsnYSF6n, HV_BINOP_NEQ, 1, m, &cBinop_HsnYSF6n_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_JMf04BBO, 1, m, &cVar_JMf04BBO_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_HsnYSF6n, HV_BINOP_NEQ, 1, m, &cBinop_HsnYSF6n_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_JMf04BBO, 1, m, &cVar_JMf04BBO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_JMf04BBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HtmXvMjw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_EqwhxC9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0k3Cer3I_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eCL66pGU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_0k3Cer3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HsnYSF6n, HV_BINOP_NEQ, 1, m, &cBinop_HsnYSF6n_sendMessage);
}

void Heavy_vSwellST::cCast_eCL66pGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JMf04BBO, 0, m, &cVar_JMf04BBO_sendMessage);
}

void Heavy_vSwellST::cBinop_HsnYSF6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EqwhxC9k, 1, m, &cIf_EqwhxC9k_sendMessage);
}

void Heavy_vSwellST::cCast_o6HATbE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HsnYSF6n, HV_BINOP_NEQ, 0, m, &cBinop_HsnYSF6n_sendMessage);
}

void Heavy_vSwellST::cCast_6uxWWPKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EqwhxC9k, 0, m, &cIf_EqwhxC9k_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_Cvbib7Ns_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H60Ywa7D_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vbm6uogd_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_H60Ywa7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_13wH22rG, 0, m, &cVar_13wH22rG_sendMessage);
}

void Heavy_vSwellST::cCast_vbm6uogd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_66gw531Z_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wi0OmogZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c1nOdUnp_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_HtmXvMjw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G2vZCkyZ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v3Asi4l8_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_G2vZCkyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dBS2mylK, 0, m, &cVar_dBS2mylK_sendMessage);
}

void Heavy_vSwellST::cCast_v3Asi4l8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_38WJZEw0_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_dBS2mylK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eDJZONPa, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eDJZONPa_sendMessage);
}

void Heavy_vSwellST::cVar_13wH22rG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_klXYaPdt, HV_BINOP_LESS_THAN, 1, m, &cBinop_klXYaPdt_sendMessage);
}

void Heavy_vSwellST::cBinop_eDJZONPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5uFVj4qs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_klXYaPdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_voSfg638_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_66gw531Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eDJZONPa, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eDJZONPa_sendMessage);
}

void Heavy_vSwellST::cMsg_38WJZEw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_klXYaPdt, HV_BINOP_LESS_THAN, 1, m, &cBinop_klXYaPdt_sendMessage);
}

void Heavy_vSwellST::cSlice_PFrs5tGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_frSezkYW_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_9tMY4GIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_O44xwAnh, 0, m, &cIf_O44xwAnh_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_3Zl5RvPP, 0, m, &cIf_3Zl5RvPP_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_QRrpO2Zt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_oxsV0dKU, 0, m, &cIf_oxsV0dKU_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_dC7e2fnY, 0, m, &cIf_dC7e2fnY_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_1XT4XiBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jJZ11Seb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Sl4FfOD6, 0, m, &cIf_Sl4FfOD6_sendMessage);
}

void Heavy_vSwellST::cUnop_3FX429LB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZiY8XOyh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CvpK1ifn, HV_BINOP_EQ, 1, m, &cBinop_CvpK1ifn_sendMessage);
}

void Heavy_vSwellST::cUnop_UuFqlLpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZiY8XOyh_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CvpK1ifn, HV_BINOP_EQ, 1, m, &cBinop_CvpK1ifn_sendMessage);
}

void Heavy_vSwellST::cIf_Sl4FfOD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_UuFqlLpt_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_3FX429LB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_jJZ11Seb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Sl4FfOD6, 1, m, &cIf_Sl4FfOD6_sendMessage);
}

void Heavy_vSwellST::cIf_3Zl5RvPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_P5sEVbcC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_dC7e2fnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_O44xwAnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_P5sEVbcC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_oxsV0dKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_frSezkYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CvpK1ifn, HV_BINOP_EQ, 0, m, &cBinop_CvpK1ifn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_xBb065n2_sendMessage);
}

void Heavy_vSwellST::cBinop_ZiY8XOyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nKmfd9ZF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G9QbUpPj_sendMessage);
}

void Heavy_vSwellST::cBinop_CvpK1ifn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xhKuj5h1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IBQI6df9_sendMessage);
}

void Heavy_vSwellST::cCast_xhKuj5h1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Zl5RvPP, 1, m, &cIf_3Zl5RvPP_sendMessage);
}

void Heavy_vSwellST::cCast_IBQI6df9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oxsV0dKU, 1, m, &cIf_oxsV0dKU_sendMessage);
}

void Heavy_vSwellST::cCast_nKmfd9ZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O44xwAnh, 1, m, &cIf_O44xwAnh_sendMessage);
}

void Heavy_vSwellST::cCast_G9QbUpPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dC7e2fnY, 1, m, &cIf_dC7e2fnY_sendMessage);
}

void Heavy_vSwellST::cBinop_xBb065n2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwellST::cSwitchcase_9QfyKrgG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6KV3SWMY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6KV3SWMY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Rr7uKltH, 1, m, &cDelay_Rr7uKltH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_22d8Yvml_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_Rr7uKltH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Rr7uKltH, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fwz7m2nb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pBw4baSl_sendMessage);
  cSwitchcase_4QeqrQbt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_6KV3SWMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rr7uKltH, 0, m, &cDelay_Rr7uKltH_sendMessage);
}

void Heavy_vSwellST::cCast_22d8Yvml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rr7uKltH, 0, m, &cDelay_Rr7uKltH_sendMessage);
}

void Heavy_vSwellST::cPack_Ym8EIEEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vXqPO1rx_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_LV0pggu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JuJtfVtr_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_h6TOiQ9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_9QfyKrgG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_xgGeGy4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Ym8EIEEj, 0, m, &cPack_Ym8EIEEj_sendMessage);
}

void Heavy_vSwellST::cCast_UjS81c5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LV0pggu3, 0, m, &cVar_LV0pggu3_sendMessage);
}

void Heavy_vSwellST::cMsg_JuJtfVtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_2F3wGoZo, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_vXqPO1rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_2F3wGoZo, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_4QeqrQbt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_m1MCsG6D_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_m1MCsG6D_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5qQai8Y6, 1, m, &cDelay_5qQai8Y6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xcDlPXod_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_5qQai8Y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5qQai8Y6, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NQTQTo1n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yK82X0dL_sendMessage);
  cSwitchcase_Kg2IIqsv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_m1MCsG6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5qQai8Y6, 0, m, &cDelay_5qQai8Y6_sendMessage);
}

void Heavy_vSwellST::cCast_xcDlPXod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5qQai8Y6, 0, m, &cDelay_5qQai8Y6_sendMessage);
}

void Heavy_vSwellST::cPack_3laRlUTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FJBbJtXd_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_bR01cUrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m42KjZTL_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_vwEXap3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_4QeqrQbt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_fwz7m2nb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bR01cUrC, 0, m, &cVar_bR01cUrC_sendMessage);
}

void Heavy_vSwellST::cCast_pBw4baSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_3laRlUTP, 0, m, &cPack_3laRlUTP_sendMessage);
}

void Heavy_vSwellST::cMsg_m42KjZTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_2F3wGoZo, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_FJBbJtXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_2F3wGoZo, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_Kg2IIqsv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_THam6ymU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_THam6ymU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7C6CZmSe, 1, m, &cDelay_7C6CZmSe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K6tPYU7y_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_7C6CZmSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7C6CZmSe, m);
}

void Heavy_vSwellST::cMsg_THam6ymU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7C6CZmSe, 0, m, &cDelay_7C6CZmSe_sendMessage);
}

void Heavy_vSwellST::cCast_K6tPYU7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7C6CZmSe, 0, m, &cDelay_7C6CZmSe_sendMessage);
}

void Heavy_vSwellST::cPack_mxWDXeLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7SD58d0y_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_O2IKjTxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RaOJ9Qe5_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_ysnWcYO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_Kg2IIqsv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_NQTQTo1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_O2IKjTxU, 0, m, &cVar_O2IKjTxU_sendMessage);
}

void Heavy_vSwellST::cCast_yK82X0dL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_mxWDXeLC, 0, m, &cPack_mxWDXeLC_sendMessage);
}

void Heavy_vSwellST::cMsg_RaOJ9Qe5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_2F3wGoZo, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_7SD58d0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_2F3wGoZo, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_hxZdaTIy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fozeNaUB_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_fozeNaUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wi0OmogZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c1nOdUnp_sendMessage);
}

void Heavy_vSwellST::cVar_kdAJQpXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RsGQBVbB_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_OPyjHWHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_mxWDXeLC, 1, m, &cPack_mxWDXeLC_sendMessage);
}

void Heavy_vSwellST::cMsg_KIXswUVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hvGFlQno_sendMessage);
}

void Heavy_vSwellST::cSystem_hvGFlQno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M29omxKv, HV_BINOP_MULTIPLY, 1, m, &cBinop_M29omxKv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bGCjGErh, HV_BINOP_MULTIPLY, 1, m, &cBinop_bGCjGErh_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_u5MadQ2F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_Mpp4ZcQ0_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_Mpp4ZcQ0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GCX8BkeO_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_sQwZUAOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sQwZUAOI, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sQwZUAOI, 0, m, &cDelay_sQwZUAOI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UKdKTjZD, 0, m, &cVar_UKdKTjZD_sendMessage);
}

void Heavy_vSwellST::cCast_GCX8BkeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mpp4ZcQ0_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_sQwZUAOI, 0, m, &cDelay_sQwZUAOI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UKdKTjZD, 0, m, &cVar_UKdKTjZD_sendMessage);
}

void Heavy_vSwellST::cMsg_PHcKXdDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7X8oBa8m_sendMessage);
}

void Heavy_vSwellST::cSystem_7X8oBa8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DAf5j2o8_sendMessage);
}

void Heavy_vSwellST::cVar_2x57PHa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KPvwJmbF, HV_BINOP_MULTIPLY, 0, m, &cBinop_KPvwJmbF_sendMessage);
}

void Heavy_vSwellST::cMsg_Mpp4ZcQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sQwZUAOI, 0, m, &cDelay_sQwZUAOI_sendMessage);
}

void Heavy_vSwellST::cBinop_stYZ2eYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sQwZUAOI, 2, m, &cDelay_sQwZUAOI_sendMessage);
}

void Heavy_vSwellST::cBinop_DAf5j2o8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KPvwJmbF, HV_BINOP_MULTIPLY, 1, m, &cBinop_KPvwJmbF_sendMessage);
}

void Heavy_vSwellST::cBinop_KPvwJmbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_stYZ2eYs_sendMessage);
}

void Heavy_vSwellST::cVar_UKdKTjZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrCTdQJr, HV_BINOP_SUBTRACT, 0, m, &cBinop_jrCTdQJr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_t49Lq4YW_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_GueXIvXR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uwZE522L_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_htezVL5x_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_uwZE522L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U8MQNAKf, 0, m, &cVar_U8MQNAKf_sendMessage);
}

void Heavy_vSwellST::cCast_htezVL5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jZxtlZ84_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uJqqJ7p1_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_kaBfMVk9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3k3vZn5N, 0, m, &cSlice_3k3vZn5N_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5i3XKb89, 0, m, &cSlice_5i3XKb89_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zdhZScqM_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_WLrs0mAP, 0, m, &cSlice_WLrs0mAP_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_4yceTXNW, 0, m, &cSlice_4yceTXNW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_COpd1rut_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UDqwOx3u_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_3k3vZn5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_c7v6iRuN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_c7v6iRuN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_5i3XKb89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S4aAkMxv_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HbqUqYuz_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S4aAkMxv_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HbqUqYuz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_ljKlyqMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T4wdYyFC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5IgvenvX_sendMessage);
}

void Heavy_vSwellST::cVar_deu2nYAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JpnEw6pV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_JpnEw6pV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EMrTi90o_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_M29omxKv, HV_BINOP_MULTIPLY, 0, m, &cBinop_M29omxKv_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_Vbtd0YDf, HV_BINOP_DIVIDE, 1, m, &cBinop_Vbtd0YDf_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_2x57PHa6, 0, m, &cVar_2x57PHa6_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cCast_EMrTi90o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tAq5VTHF_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_pbmPnpEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xEQ1yD3O, HV_BINOP_SUBTRACT, 1, m, &cBinop_xEQ1yD3O_sendMessage);
}

void Heavy_vSwellST::cVar_88xreAl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U8MQNAKf, 0, m, &cVar_U8MQNAKf_sendMessage);
}

void Heavy_vSwellST::cVar_U8MQNAKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQ5Apeh0, HV_BINOP_ADD, 0, m, &cBinop_rQ5Apeh0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AGhiX020, HV_BINOP_ADD, 0, m, &cBinop_AGhiX020_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ovpS4sT3, m);
}

void Heavy_vSwellST::cSlice_WLrs0mAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T4wdYyFC_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5IgvenvX_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_4yceTXNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PSk3dXJx_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZhcRPet9_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_xEJNASo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UKdKTjZD, 1, m, &cVar_UKdKTjZD_sendMessage);
}

void Heavy_vSwellST::cBinop_bGCjGErh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xEJNASo3_sendMessage);
}

void Heavy_vSwellST::cBinop_M29omxKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zu1wu4ot_sendMessage);
}

void Heavy_vSwellST::cBinop_zu1wu4ot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrCTdQJr, HV_BINOP_SUBTRACT, 1, m, &cBinop_jrCTdQJr_sendMessage);
}

void Heavy_vSwellST::cBinop_jrCTdQJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UKdKTjZD, 1, m, &cVar_UKdKTjZD_sendMessage);
}

void Heavy_vSwellST::cMsg_DbUd3EWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_u5MadQ2F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_O6Y4QEDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_u5MadQ2F_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AGhiX020, HV_BINOP_ADD, 1, m, &cBinop_AGhiX020_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQ5Apeh0, HV_BINOP_ADD, 1, m, &cBinop_rQ5Apeh0_sendMessage);
}

void Heavy_vSwellST::cBinop_t49Lq4YW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GueXIvXR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_rQ5Apeh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U8MQNAKf, 1, m, &cVar_U8MQNAKf_sendMessage);
}

void Heavy_vSwellST::cBinop_Vbtd0YDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iBtwHNaH, HV_BINOP_DIVIDE, 1, m, &cBinop_iBtwHNaH_sendMessage);
}

void Heavy_vSwellST::cBinop_iBtwHNaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AGhiX020, HV_BINOP_ADD, 1, m, &cBinop_AGhiX020_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQ5Apeh0, HV_BINOP_ADD, 1, m, &cBinop_rQ5Apeh0_sendMessage);
}

void Heavy_vSwellST::cCast_5IgvenvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vbtd0YDf, HV_BINOP_DIVIDE, 0, m, &cBinop_Vbtd0YDf_sendMessage);
}

void Heavy_vSwellST::cCast_T4wdYyFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bGCjGErh, HV_BINOP_MULTIPLY, 0, m, &cBinop_bGCjGErh_sendMessage);
}

void Heavy_vSwellST::cCast_ZhcRPet9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xEQ1yD3O, HV_BINOP_SUBTRACT, 0, m, &cBinop_xEQ1yD3O_sendMessage);
}

void Heavy_vSwellST::cCast_PSk3dXJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_88xreAl7, 1, m, &cVar_88xreAl7_sendMessage);
}

void Heavy_vSwellST::cCast_uJqqJ7p1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_88xreAl7, 0, m, &cVar_88xreAl7_sendMessage);
}

void Heavy_vSwellST::cCast_jZxtlZ84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O6Y4QEDS_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_AGhiX020_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pbmPnpEI, 0, m, &cVar_pbmPnpEI_sendMessage);
}

void Heavy_vSwellST::cMsg_c7v6iRuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_u5MadQ2F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_CJ3W5L72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ljKlyqMS, 1, m, &cVar_ljKlyqMS_sendMessage);
}

void Heavy_vSwellST::cMsg_tAq5VTHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_M29omxKv, HV_BINOP_MULTIPLY, 0, m, &cBinop_M29omxKv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vbtd0YDf, HV_BINOP_DIVIDE, 1, m, &cBinop_Vbtd0YDf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2x57PHa6, 0, m, &cVar_2x57PHa6_sendMessage);
}

void Heavy_vSwellST::cCast_S4aAkMxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c7v6iRuN_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_HbqUqYuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pKwtJePx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AGhiX020, HV_BINOP_ADD, 0, m, &cBinop_AGhiX020_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_U8MQNAKf, 1, m, &cVar_U8MQNAKf_sendMessage);
}

void Heavy_vSwellST::cBinop_xEQ1yD3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iBtwHNaH, HV_BINOP_DIVIDE, 0, m, &cBinop_iBtwHNaH_sendMessage);
}

void Heavy_vSwellST::cCast_pKwtJePx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O6Y4QEDS_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_UDqwOx3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CJ3W5L72_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_zdhZScqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ljKlyqMS, 0, m, &cVar_ljKlyqMS_sendMessage);
}

void Heavy_vSwellST::cCast_COpd1rut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DbUd3EWM_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_t2ghPeIu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_1pXZz7Wc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_1pXZz7Wc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UGOjvSxE, 1, m, &cDelay_UGOjvSxE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KkT5bk9p_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_UGOjvSxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UGOjvSxE, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UjS81c5e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xgGeGy4p_sendMessage);
  cSwitchcase_9QfyKrgG_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_1pXZz7Wc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UGOjvSxE, 0, m, &cDelay_UGOjvSxE_sendMessage);
}

void Heavy_vSwellST::cCast_KkT5bk9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UGOjvSxE, 0, m, &cDelay_UGOjvSxE_sendMessage);
}

void Heavy_vSwellST::cVar_w3c8OBdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nA1LAYvr, HV_BINOP_MULTIPLY, 0, m, &cBinop_nA1LAYvr_sendMessage);
}

void Heavy_vSwellST::cMsg_ypRcBckc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I85gq0pI_sendMessage);
}

void Heavy_vSwellST::cSystem_I85gq0pI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QFrcRVGj_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_nA1LAYvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_gYPcSncH_sendMessage);
}

void Heavy_vSwellST::cBinop_GF1sjS5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nA1LAYvr, HV_BINOP_MULTIPLY, 1, m, &cBinop_nA1LAYvr_sendMessage);
}

void Heavy_vSwellST::cMsg_QFrcRVGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GF1sjS5Y_sendMessage);
}

void Heavy_vSwellST::cBinop_gYPcSncH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_A8ZQY2Ra_sendMessage);
}

void Heavy_vSwellST::cBinop_A8ZQY2Ra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_y6sQYzqR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FqGhPqsg, m);
}

void Heavy_vSwellST::cBinop_y6sQYzqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_R3kDg9RB, m);
}

void Heavy_vSwellST::cMsg_rrrcsvr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hmLHwWIS_sendMessage);
}

void Heavy_vSwellST::cSystem_hmLHwWIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_u6AsPMIT_sendMessage);
}

void Heavy_vSwellST::cDelay_j8713VtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_j8713VtR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TuE6pYu0, 0, m, &cDelay_TuE6pYu0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_j8713VtR, 0, m, &cDelay_j8713VtR_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UqKEJw0T, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_TuE6pYu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TuE6pYu0, m);
  cMsg_PijKMk8O_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_0es7leME_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_2BlscKXl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_XKQAzPVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vFx0pO5V_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_KeIb71kI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EJedqb58_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_j8713VtR, 2, m, &cDelay_j8713VtR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7PMGarb2_sendMessage);
}

void Heavy_vSwellST::cMsg_vFx0pO5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_KeIb71kI, 0, m, &hTable_KeIb71kI_sendMessage);
}

void Heavy_vSwellST::cBinop_u6AsPMIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_XKQAzPVR_sendMessage);
}

void Heavy_vSwellST::cMsg_PijKMk8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_KeIb71kI, 0, m, &hTable_KeIb71kI_sendMessage);
}

void Heavy_vSwellST::cCast_7PMGarb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_j8713VtR, 0, m, &cDelay_j8713VtR_sendMessage);
}

void Heavy_vSwellST::cMsg_EJedqb58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_TuE6pYu0, 2, m, &cDelay_TuE6pYu0_sendMessage);
}

void Heavy_vSwellST::cMsg_2BlscKXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UqKEJw0T, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_xRbaUNfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_981wIgUy, HV_BINOP_SUBTRACT, 0, m, &cBinop_981wIgUy_sendMessage);
}

void Heavy_vSwellST::cMsg_dCjUy9O2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xYlqUpFF_sendMessage);
}

void Heavy_vSwellST::cSystem_xYlqUpFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XS78Onrb_sendMessage);
}

void Heavy_vSwellST::cVar_xXWaOh7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NPEvVOzo_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_OkbGSi79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OkbGSi79, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ddmKtAAO, 0, m, &cDelay_ddmKtAAO_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_a9gDhwTu, 0, m, &sTabread_a9gDhwTu_sendMessage);
}

void Heavy_vSwellST::cDelay_ddmKtAAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ddmKtAAO, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_a9gDhwTu, 0, m, &sTabread_a9gDhwTu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ddmKtAAO, 0, m, &cDelay_ddmKtAAO_sendMessage);
}

void Heavy_vSwellST::sTabread_a9gDhwTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_J8eeRZAz, HV_BINOP_SUBTRACT, 0, m, &cBinop_J8eeRZAz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_iZjcIvYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IuWJY2Gy, HV_BINOP_MAX, 0, m, &cBinop_IuWJY2Gy_sendMessage);
}

void Heavy_vSwellST::cBinop_XS78Onrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iZjcIvYi, HV_BINOP_MULTIPLY, 0, m, &cBinop_iZjcIvYi_sendMessage);
}

void Heavy_vSwellST::cBinop_981wIgUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ge0SHUTp_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_a9gDhwTu, 0, m, &sTabread_a9gDhwTu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nOhPA7OX_sendMessage);
}

void Heavy_vSwellST::cSystem_Rxgt483c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J8eeRZAz, HV_BINOP_SUBTRACT, 1, m, &cBinop_J8eeRZAz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ddmKtAAO, 2, m, &cDelay_ddmKtAAO_sendMessage);
}

void Heavy_vSwellST::cMsg_NPEvVOzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Rxgt483c_sendMessage);
}

void Heavy_vSwellST::cMsg_Ge0SHUTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OkbGSi79, 0, m, &cDelay_OkbGSi79_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ddmKtAAO, 0, m, &cDelay_ddmKtAAO_sendMessage);
}

void Heavy_vSwellST::cMsg_dN9BAd3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_IuWJY2Gy, HV_BINOP_MAX, 1, m, &cBinop_IuWJY2Gy_sendMessage);
}

void Heavy_vSwellST::cBinop_IuWJY2Gy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_981wIgUy, HV_BINOP_SUBTRACT, 1, m, &cBinop_981wIgUy_sendMessage);
}

void Heavy_vSwellST::cCast_nOhPA7OX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OkbGSi79, 0, m, &cDelay_OkbGSi79_sendMessage);
}

void Heavy_vSwellST::cBinop_NiierTOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OkbGSi79, 2, m, &cDelay_OkbGSi79_sendMessage);
}

void Heavy_vSwellST::cBinop_J8eeRZAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_NiierTOJ_sendMessage);
}

void Heavy_vSwellST::cCast_5cmmM3my_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xXWaOh7e, 0, m, &cVar_xXWaOh7e_sendMessage);
  cMsg_dCjUy9O2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_xRbaUNfD, 0, m, &cTabhead_xRbaUNfD_sendMessage);
}

void Heavy_vSwellST::cMsg_7Afag5co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_f7EbmZ1H_sendMessage);
}

void Heavy_vSwellST::cSystem_f7EbmZ1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_bwoVhaAg_sendMessage);
}

void Heavy_vSwellST::cDelay_RukeXTUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RukeXTUF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LxNvlnJr, 0, m, &cDelay_LxNvlnJr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RukeXTUF, 0, m, &cDelay_RukeXTUF_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NxqJoUBI, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_LxNvlnJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LxNvlnJr, m);
  cMsg_fawKohNL_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_JOAGO9KA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_GJhegR5j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_W0PiZc7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fnbgt1Zb_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_jcPFd4Xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mej9mPjA_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RukeXTUF, 2, m, &cDelay_RukeXTUF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C7cgcmb9_sendMessage);
}

void Heavy_vSwellST::cMsg_fnbgt1Zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_jcPFd4Xr, 0, m, &hTable_jcPFd4Xr_sendMessage);
}

void Heavy_vSwellST::cBinop_bwoVhaAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_W0PiZc7K_sendMessage);
}

void Heavy_vSwellST::cMsg_fawKohNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_jcPFd4Xr, 0, m, &hTable_jcPFd4Xr_sendMessage);
}

void Heavy_vSwellST::cCast_C7cgcmb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RukeXTUF, 0, m, &cDelay_RukeXTUF_sendMessage);
}

void Heavy_vSwellST::cMsg_Mej9mPjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_LxNvlnJr, 2, m, &cDelay_LxNvlnJr_sendMessage);
}

void Heavy_vSwellST::cMsg_GJhegR5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NxqJoUBI, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_iHeYTSPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yQJukM5Z, HV_BINOP_SUBTRACT, 0, m, &cBinop_yQJukM5Z_sendMessage);
}

void Heavy_vSwellST::cMsg_EOPLU2pP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r76qlwwx_sendMessage);
}

void Heavy_vSwellST::cSystem_r76qlwwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jOkF25vm_sendMessage);
}

void Heavy_vSwellST::cVar_ipL3gcF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wynsaV6L_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_pqzSOeGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pqzSOeGx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hsHAbhCV, 0, m, &cDelay_hsHAbhCV_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_01ojBHIV, 0, m, &sTabread_01ojBHIV_sendMessage);
}

void Heavy_vSwellST::cDelay_hsHAbhCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hsHAbhCV, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_01ojBHIV, 0, m, &sTabread_01ojBHIV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hsHAbhCV, 0, m, &cDelay_hsHAbhCV_sendMessage);
}

void Heavy_vSwellST::sTabread_01ojBHIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_5Q7CSrTr, HV_BINOP_SUBTRACT, 0, m, &cBinop_5Q7CSrTr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_JSLDdQ7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JBlmzsBO, HV_BINOP_MAX, 0, m, &cBinop_JBlmzsBO_sendMessage);
}

void Heavy_vSwellST::cBinop_jOkF25vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JSLDdQ7K, HV_BINOP_MULTIPLY, 0, m, &cBinop_JSLDdQ7K_sendMessage);
}

void Heavy_vSwellST::cBinop_yQJukM5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cW6UydMO_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_01ojBHIV, 0, m, &sTabread_01ojBHIV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sES2L3gg_sendMessage);
}

void Heavy_vSwellST::cSystem_L9TYLzTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Q7CSrTr, HV_BINOP_SUBTRACT, 1, m, &cBinop_5Q7CSrTr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hsHAbhCV, 2, m, &cDelay_hsHAbhCV_sendMessage);
}

void Heavy_vSwellST::cMsg_wynsaV6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L9TYLzTQ_sendMessage);
}

void Heavy_vSwellST::cMsg_cW6UydMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pqzSOeGx, 0, m, &cDelay_pqzSOeGx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hsHAbhCV, 0, m, &cDelay_hsHAbhCV_sendMessage);
}

void Heavy_vSwellST::cMsg_E8OBtemA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_JBlmzsBO, HV_BINOP_MAX, 1, m, &cBinop_JBlmzsBO_sendMessage);
}

void Heavy_vSwellST::cBinop_JBlmzsBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yQJukM5Z, HV_BINOP_SUBTRACT, 1, m, &cBinop_yQJukM5Z_sendMessage);
}

void Heavy_vSwellST::cCast_sES2L3gg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pqzSOeGx, 0, m, &cDelay_pqzSOeGx_sendMessage);
}

void Heavy_vSwellST::cBinop_wfOnqKzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pqzSOeGx, 2, m, &cDelay_pqzSOeGx_sendMessage);
}

void Heavy_vSwellST::cBinop_5Q7CSrTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wfOnqKzD_sendMessage);
}

void Heavy_vSwellST::cCast_HoqW3v0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ipL3gcF9, 0, m, &cVar_ipL3gcF9_sendMessage);
  cMsg_EOPLU2pP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_iHeYTSPk, 0, m, &cTabhead_iHeYTSPk_sendMessage);
}

void Heavy_vSwellST::cUnop_aqdFHuPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SXGVRNNH, m);
}

void Heavy_vSwellST::cCast_wi0OmogZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_klAt1O2B_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kdAJQpXS, 0, m, &cVar_kdAJQpXS_sendMessage);
}

void Heavy_vSwellST::cCast_c1nOdUnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_t2ghPeIu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_XkJL21na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dBS2mylK, 0, m, &cVar_dBS2mylK_sendMessage);
}

void Heavy_vSwellST::cCast_1X6382k5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jZYzRI8K, HV_BINOP_SUBTRACT, 0, m, &cBinop_jZYzRI8K_sendMessage);
}

void Heavy_vSwellST::cBinop_jZYzRI8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_13wH22rG, 0, m, &cVar_13wH22rG_sendMessage);
}

void Heavy_vSwellST::cSend_klAt1O2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RCVF8VlO_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_P5sEVbcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hxZdaTIy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_yYLs5G2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_kaBfMVk9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_RsGQBVbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2F3wGoZo, 0, m, NULL);
}

void Heavy_vSwellST::cSend_Mo2a3ibK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IkMyKmNk_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_QtibxjIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UGOjvSxE, 1, m, &cDelay_UGOjvSxE_sendMessage);
}

void Heavy_vSwellST::cBinop_0Ykg1xnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_aqdFHuPO_sendMessage);
}

void Heavy_vSwellST::cReceive_08sCoVZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jZYzRI8K, HV_BINOP_SUBTRACT, 1, m, &cBinop_jZYzRI8K_sendMessage);
}

void Heavy_vSwellST::cReceive_V9dxL51G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PHcKXdDq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2x57PHa6, 0, m, &cVar_2x57PHa6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1XT4XiBN, 0, m, &cVar_1XT4XiBN_sendMessage);
  cMsg_KIXswUVK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pbmPnpEI, 0, m, &cVar_pbmPnpEI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_deu2nYAm, 0, m, &cVar_deu2nYAm_sendMessage);
  cMsg_ypRcBckc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_w3c8OBdy, 0, m, &cVar_w3c8OBdy_sendMessage);
  cMsg_rrrcsvr5_sendMessage(_c, 0, m);
  cMsg_7Afag5co_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OPyjHWHy, 0, m, &cVar_OPyjHWHy_sendMessage);
  cMsg_dN9BAd3g_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xXWaOh7e, 0, m, &cVar_xXWaOh7e_sendMessage);
  cMsg_dCjUy9O2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_xRbaUNfD, 0, m, &cTabhead_xRbaUNfD_sendMessage);
  cMsg_E8OBtemA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ipL3gcF9, 0, m, &cVar_ipL3gcF9_sendMessage);
  cMsg_EOPLU2pP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_iHeYTSPk, 0, m, &cTabhead_iHeYTSPk_sendMessage);
}

void Heavy_vSwellST::cReceive_UghqXrFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_PFrs5tGq, 0, m, &cSlice_PFrs5tGq_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_9tMY4GIr, 0, m, &cSlice_9tMY4GIr_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_QRrpO2Zt, 0, m, &cSlice_QRrpO2Zt_sendMessage);
}

void Heavy_vSwellST::cReceive_v0387Lgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Mh9Ly15k, m);
}

void Heavy_vSwellST::cReceive_RCVF8VlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h6TOiQ9X_sendMessage(_c, 0, m);
  cMsg_vwEXap3G_sendMessage(_c, 0, m);
  cMsg_ysnWcYO1_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_J5TQeArv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wi0OmogZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c1nOdUnp_sendMessage);
}

void Heavy_vSwellST::cReceive_nQtTx3zZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bR01cUrC, 1, m, &cVar_bR01cUrC_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_Ym8EIEEj, 1, m, &cPack_Ym8EIEEj_sendMessage);
}

void Heavy_vSwellST::cReceive_EMoLMfNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Ym8EIEEj, 2, m, &cPack_Ym8EIEEj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rr7uKltH, 1, m, &cDelay_Rr7uKltH_sendMessage);
}

void Heavy_vSwellST::cReceive_CmisqW5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_3laRlUTP, 1, m, &cPack_3laRlUTP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_O2IKjTxU, 1, m, &cVar_O2IKjTxU_sendMessage);
}

void Heavy_vSwellST::cReceive_Gu2uh9Ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_3laRlUTP, 2, m, &cPack_3laRlUTP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5qQai8Y6, 1, m, &cDelay_5qQai8Y6_sendMessage);
}

void Heavy_vSwellST::cReceive_ZS6Y4MAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_mxWDXeLC, 2, m, &cPack_mxWDXeLC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7C6CZmSe, 1, m, &cDelay_7C6CZmSe_sendMessage);
}

void Heavy_vSwellST::cReceive_IkMyKmNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OPyjHWHy, 1, m, &cVar_OPyjHWHy_sendMessage);
  cMsg_yYLs5G2X_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kdAJQpXS, 1, m, &cVar_kdAJQpXS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LV0pggu3, 1, m, &cVar_LV0pggu3_sendMessage);
}

void Heavy_vSwellST::cReceive_xvzTp40z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Mo2a3ibK_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_QL0Ce7n6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_QtibxjIU_sendMessage);
}

void Heavy_vSwellST::cReceive_HUGDIaT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MKdxfRU6, m);
}

void Heavy_vSwellST::cReceive_iDKZyzga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ghed3sZ9, m);
}

void Heavy_vSwellST::cReceive_xJp9d5IM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1X6382k5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XkJL21na_sendMessage);
}

void Heavy_vSwellST::cReceive_NhXVCGsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0Ykg1xnA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_V1ESP7TQ, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwellST::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_UqKEJw0T, VIf(I0));
    __hv_tabwrite_f(&sTabwrite_NxqJoUBI, VIf(I1));
    __hv_varread_f(&sVarf_MKdxfRU6, VOf(Bf0));
    __hv_varread_f(&sVarf_ghed3sZ9, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_FqGhPqsg, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_R3kDg9RB, VOf(Bf1));
    __hv_rpole_f(&sRPole_gvIYpzzE, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_V1ESP7TQ, VOf(Bf0));
    __hv_varread_f(&sVarf_SXGVRNNH, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf2));
    __hv_gt_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_sqrt_f(VIf(Bf3), VOf(Bf3));
    __hv_and_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf2), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_34b7UgwQ, VIf(Bf2), &sEnv_34b7UgwQ_sendMessage);
    __hv_tabread_f(&sTabread_01ojBHIV, VOf(Bf2));
    __hv_line_f(&sLine_2F3wGoZo, VOf(Bf0));
    __hv_varread_f(&sVarf_Mh9Ly15k, VOf(Bf1));
    __hv_pow_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_ovpS4sT3, VOf(Bf0));
    __hv_max_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_tabread_f(&sTabread_a9gDhwTu, VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwellST::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwellST::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
