/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELLST_HPP_
#define _HEAVY_CONTEXT_VSWELLST_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSlice.h"
#include "HvControlSystem.h"
#include "HvControlBinop.h"
#include "HvControlVar.h"
#include "HvSignalEnvelope.h"
#include "HvSignalDel1.h"
#include "HvSignalRPole.h"
#include "HvSignalVar.h"
#include "HvControlDelay.h"
#include "HvControlCast.h"
#include "HvTable.h"
#include "HvControlIf.h"
#include "HvMath.h"
#include "HvSignalLine.h"
#include "HvSignalTabread.h"
#include "HvControlPack.h"
#include "HvControlTabhead.h"
#include "HvSignalTabwrite.h"
#include "HvControlUnop.h"

class Heavy_vSwellST : public HeavyContext {

 public:
  Heavy_vSwellST(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwellST();

  const char *getName() override { return "vSwellST"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
        TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_34b7UgwQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5uFVj4qs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_g0Z90FPE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_CNPmDsD4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1uotDkCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_eY4Jvawl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MVSukJ50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_66nyDXdI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XhwalkxR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uyL4q6TK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6GKLy317_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_voSfg638_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_D32LADbA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_uYjiDyPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JMf04BBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EqwhxC9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0k3Cer3I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eCL66pGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HsnYSF6n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o6HATbE4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6uxWWPKe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Cvbib7Ns_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_H60Ywa7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vbm6uogd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HtmXvMjw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_G2vZCkyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v3Asi4l8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dBS2mylK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_13wH22rG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eDJZONPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_klXYaPdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_66gw531Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_38WJZEw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_PFrs5tGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_9tMY4GIr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_QRrpO2Zt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1XT4XiBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3FX429LB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UuFqlLpt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Sl4FfOD6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jJZ11Seb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3Zl5RvPP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dC7e2fnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_O44xwAnh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oxsV0dKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_frSezkYW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZiY8XOyh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CvpK1ifn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xhKuj5h1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IBQI6df9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nKmfd9ZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G9QbUpPj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xBb065n2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9QfyKrgG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Rr7uKltH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6KV3SWMY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_22d8Yvml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Ym8EIEEj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LV0pggu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h6TOiQ9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xgGeGy4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UjS81c5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JuJtfVtr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vXqPO1rx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4QeqrQbt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_5qQai8Y6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m1MCsG6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xcDlPXod_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_3laRlUTP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bR01cUrC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vwEXap3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fwz7m2nb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pBw4baSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m42KjZTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FJBbJtXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Kg2IIqsv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7C6CZmSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_THam6ymU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K6tPYU7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_mxWDXeLC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_O2IKjTxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ysnWcYO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NQTQTo1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yK82X0dL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RaOJ9Qe5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7SD58d0y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hxZdaTIy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_fozeNaUB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kdAJQpXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OPyjHWHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KIXswUVK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hvGFlQno_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_u5MadQ2F_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_sQwZUAOI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GCX8BkeO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PHcKXdDq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7X8oBa8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2x57PHa6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Mpp4ZcQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_stYZ2eYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DAf5j2o8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KPvwJmbF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UKdKTjZD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GueXIvXR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_uwZE522L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_htezVL5x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kaBfMVk9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3k3vZn5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_5i3XKb89_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ljKlyqMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_deu2nYAm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JpnEw6pV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_EMrTi90o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pbmPnpEI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_88xreAl7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_U8MQNAKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_WLrs0mAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_4yceTXNW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xEJNASo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bGCjGErh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M29omxKv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zu1wu4ot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jrCTdQJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DbUd3EWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O6Y4QEDS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t49Lq4YW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rQ5Apeh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vbtd0YDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iBtwHNaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5IgvenvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T4wdYyFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZhcRPet9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PSk3dXJx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uJqqJ7p1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jZxtlZ84_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AGhiX020_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c7v6iRuN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CJ3W5L72_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tAq5VTHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S4aAkMxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HbqUqYuz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xEQ1yD3O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pKwtJePx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UDqwOx3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zdhZScqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_COpd1rut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_t2ghPeIu_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_UGOjvSxE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1pXZz7Wc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KkT5bk9p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w3c8OBdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ypRcBckc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_I85gq0pI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nA1LAYvr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GF1sjS5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QFrcRVGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gYPcSncH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A8ZQY2Ra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y6sQYzqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rrrcsvr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hmLHwWIS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_j8713VtR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TuE6pYu0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0es7leME_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_XKQAzPVR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_KeIb71kI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vFx0pO5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u6AsPMIT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PijKMk8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7PMGarb2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EJedqb58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2BlscKXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_xRbaUNfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dCjUy9O2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xYlqUpFF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xXWaOh7e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_OkbGSi79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ddmKtAAO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_a9gDhwTu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iZjcIvYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XS78Onrb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_981wIgUy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Rxgt483c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NPEvVOzo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ge0SHUTp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dN9BAd3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IuWJY2Gy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nOhPA7OX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NiierTOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J8eeRZAz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5cmmM3my_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7Afag5co_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_f7EbmZ1H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RukeXTUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LxNvlnJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JOAGO9KA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_W0PiZc7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_jcPFd4Xr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fnbgt1Zb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bwoVhaAg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fawKohNL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C7cgcmb9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Mej9mPjA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GJhegR5j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_iHeYTSPk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EOPLU2pP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_r76qlwwx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ipL3gcF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_pqzSOeGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hsHAbhCV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_01ojBHIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JSLDdQ7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jOkF25vm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yQJukM5Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_L9TYLzTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wynsaV6L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cW6UydMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E8OBtemA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JBlmzsBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sES2L3gg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wfOnqKzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Q7CSrTr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HoqW3v0y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aqdFHuPO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wi0OmogZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c1nOdUnp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XkJL21na_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1X6382k5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jZYzRI8K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_klAt1O2B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P5sEVbcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yYLs5G2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RsGQBVbB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Mo2a3ibK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QtibxjIU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0Ykg1xnA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_08sCoVZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_V9dxL51G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UghqXrFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_v0387Lgi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RCVF8VlO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_J5TQeArv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nQtTx3zZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EMoLMfNw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CmisqW5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Gu2uh9Ur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZS6Y4MAt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IkMyKmNk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xvzTp40z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QL0Ce7n6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HUGDIaT1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iDKZyzga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xJp9d5IM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NhXVCGsR_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_UqKEJw0T;
  SignalTabwrite sTabwrite_NxqJoUBI;
  SignalRPole sRPole_gvIYpzzE;
  SignalEnvelope sEnv_34b7UgwQ;
  SignalTabread sTabread_01ojBHIV;
  SignalLine sLine_2F3wGoZo;
  SignalTabread sTabread_a9gDhwTu;
  ControlSlice cSlice_g0Z90FPE;
  ControlSlice cSlice_CNPmDsD4;
  ControlVar cVar_1uotDkCA;
  ControlIf cIf_eY4Jvawl;
  ControlBinop cBinop_XhwalkxR;
  ControlSlice cSlice_D32LADbA;
  ControlSlice cSlice_uYjiDyPt;
  ControlVar cVar_JMf04BBO;
  ControlIf cIf_EqwhxC9k;
  ControlBinop cBinop_HsnYSF6n;
  ControlVar cVar_dBS2mylK;
  ControlVar cVar_13wH22rG;
  ControlBinop cBinop_eDJZONPa;
  ControlBinop cBinop_klXYaPdt;
  ControlSlice cSlice_PFrs5tGq;
  ControlSlice cSlice_9tMY4GIr;
  ControlSlice cSlice_QRrpO2Zt;
  ControlVar cVar_1XT4XiBN;
  ControlIf cIf_Sl4FfOD6;
  ControlBinop cBinop_jJZ11Seb;
  ControlIf cIf_3Zl5RvPP;
  ControlIf cIf_dC7e2fnY;
  ControlIf cIf_O44xwAnh;
  ControlIf cIf_oxsV0dKU;
  ControlBinop cBinop_frSezkYW;
  ControlBinop cBinop_ZiY8XOyh;
  ControlBinop cBinop_CvpK1ifn;
  ControlBinop cBinop_xBb065n2;
  ControlDelay cDelay_Rr7uKltH;
  ControlPack cPack_Ym8EIEEj;
  ControlVar cVar_LV0pggu3;
  ControlDelay cDelay_5qQai8Y6;
  ControlPack cPack_3laRlUTP;
  ControlVar cVar_bR01cUrC;
  ControlDelay cDelay_7C6CZmSe;
  ControlPack cPack_mxWDXeLC;
  ControlVar cVar_O2IKjTxU;
  ControlVar cVar_kdAJQpXS;
  ControlVar cVar_OPyjHWHy;
  SignalVarf sVarf_ovpS4sT3;
  ControlDelay cDelay_sQwZUAOI;
  ControlVar cVar_2x57PHa6;
  ControlBinop cBinop_stYZ2eYs;
  ControlBinop cBinop_DAf5j2o8;
  ControlBinop cBinop_KPvwJmbF;
  ControlVar cVar_UKdKTjZD;
  ControlSlice cSlice_3k3vZn5N;
  ControlSlice cSlice_5i3XKb89;
  ControlVar cVar_ljKlyqMS;
  ControlVar cVar_deu2nYAm;
  ControlVar cVar_pbmPnpEI;
  ControlVar cVar_88xreAl7;
  ControlVar cVar_U8MQNAKf;
  ControlSlice cSlice_WLrs0mAP;
  ControlSlice cSlice_4yceTXNW;
  ControlBinop cBinop_xEJNASo3;
  ControlBinop cBinop_bGCjGErh;
  ControlBinop cBinop_M29omxKv;
  ControlBinop cBinop_zu1wu4ot;
  ControlBinop cBinop_jrCTdQJr;
  ControlBinop cBinop_t49Lq4YW;
  ControlBinop cBinop_rQ5Apeh0;
  ControlBinop cBinop_Vbtd0YDf;
  ControlBinop cBinop_iBtwHNaH;
  ControlBinop cBinop_AGhiX020;
  ControlBinop cBinop_xEQ1yD3O;
  ControlDelay cDelay_UGOjvSxE;
  ControlVar cVar_w3c8OBdy;
  ControlBinop cBinop_nA1LAYvr;
  ControlBinop cBinop_GF1sjS5Y;
  SignalVarf sVarf_R3kDg9RB;
  ControlBinop cBinop_gYPcSncH;
  ControlBinop cBinop_A8ZQY2Ra;
  ControlBinop cBinop_y6sQYzqR;
  SignalVarf sVarf_FqGhPqsg;
  ControlDelay cDelay_j8713VtR;
  ControlDelay cDelay_TuE6pYu0;
  ControlBinop cBinop_XKQAzPVR;
  HvTable hTable_KeIb71kI;
  ControlBinop cBinop_u6AsPMIT;
  ControlTabhead cTabhead_xRbaUNfD;
  ControlVar cVar_xXWaOh7e;
  ControlDelay cDelay_OkbGSi79;
  ControlDelay cDelay_ddmKtAAO;
  ControlBinop cBinop_iZjcIvYi;
  ControlBinop cBinop_XS78Onrb;
  ControlBinop cBinop_981wIgUy;
  ControlBinop cBinop_IuWJY2Gy;
  ControlBinop cBinop_NiierTOJ;
  ControlBinop cBinop_J8eeRZAz;
  ControlDelay cDelay_RukeXTUF;
  ControlDelay cDelay_LxNvlnJr;
  ControlBinop cBinop_W0PiZc7K;
  HvTable hTable_jcPFd4Xr;
  ControlBinop cBinop_bwoVhaAg;
  ControlTabhead cTabhead_iHeYTSPk;
  ControlVar cVar_ipL3gcF9;
  ControlDelay cDelay_pqzSOeGx;
  ControlDelay cDelay_hsHAbhCV;
  ControlBinop cBinop_JSLDdQ7K;
  ControlBinop cBinop_jOkF25vm;
  ControlBinop cBinop_yQJukM5Z;
  ControlBinop cBinop_JBlmzsBO;
  ControlBinop cBinop_wfOnqKzD;
  ControlBinop cBinop_5Q7CSrTr;
  ControlBinop cBinop_jZYzRI8K;
  ControlBinop cBinop_P5sEVbcC;
  ControlBinop cBinop_QtibxjIU;
  ControlBinop cBinop_0Ykg1xnA;
  SignalVarf sVarf_Mh9Ly15k;
  SignalVarf sVarf_MKdxfRU6;
  SignalVarf sVarf_ghed3sZ9;
  SignalVarf sVarf_SXGVRNNH;
  SignalVarf sVarf_V1ESP7TQ;
};

#endif // _HEAVY_CONTEXT_VSWELLST_HPP_
